View Source AWS.Account (aws-elixir v1.0.11)
Operations for Amazon Web Services Account Management
Link to this section Summary
Functions
Accepts the request that originated from StartPrimaryEmailUpdate to update the
primary email address (also known as the root user email address) for the
specified account.
Deletes the specified alternate contact from an Amazon Web Services account.
Disables (opts-out) a particular Region for an account.
Enables (opts-in) a particular Region for an account.
Retrieves information about the specified account including its account name, account ID, account creation date and time, and account state.
Retrieves the specified alternate contact attached to an Amazon Web Services account.
Retrieves the primary contact information of an Amazon Web Services account.
Retrieves information about the GovCloud account linked to the specified standard account (if it exists) including the GovCloud account ID and state.
Retrieves the primary email address for the specified account.
Retrieves the opt-in status of a particular Region.
Lists all the Regions for a given account and their respective opt-in statuses.
Updates the account name of the specified account.
Modifies the specified alternate contact attached to an Amazon Web Services account.
Updates the primary contact information of an Amazon Web Services account.
Starts the process to update the primary email address for the specified account.
Link to this section Functions
Accepts the request that originated from StartPrimaryEmailUpdate to update the
primary email address (also known as the root user email address) for the
specified account.
Deletes the specified alternate contact from an Amazon Web Services account.
For complete details about how to use the alternate contact operations, see Update the alternate contacts for your Amazon Web Services account.
Before you can update the alternate contact information for an Amazon Web Services account that is managed by Organizations, you must first enable integration between Amazon Web Services Account Management and Organizations. For more information, see Enable trusted access for Amazon Web Services Account Management.
Disables (opts-out) a particular Region for an account.
The act of disabling a Region will remove all IAM access to any resources that reside in that Region.
Enables (opts-in) a particular Region for an account.
Retrieves information about the specified account including its account name, account ID, account creation date and time, and account state.
To use this API, an IAM user or role must have the
account:GetAccountInformation IAM permission.
Retrieves the specified alternate contact attached to an Amazon Web Services account.
For complete details about how to use the alternate contact operations, see Update the alternate contacts for your Amazon Web Services account.
Before you can update the alternate contact information for an Amazon Web Services account that is managed by Organizations, you must first enable integration between Amazon Web Services Account Management and Organizations. For more information, see Enable trusted access for Amazon Web Services Account Management.
Retrieves the primary contact information of an Amazon Web Services account.
For complete details about how to use the primary contact operations, see Update the primary contact for your Amazon Web Services account.
Retrieves information about the GovCloud account linked to the specified standard account (if it exists) including the GovCloud account ID and state.
To use this API, an IAM user or role must have the
account:GetGovCloudAccountInformation IAM permission.
Retrieves the primary email address for the specified account.
Retrieves the opt-in status of a particular Region.
Lists all the Regions for a given account and their respective opt-in statuses.
Optionally, this list can be filtered by the region-opt-status-contains
parameter.
Updates the account name of the specified account.
To use this API, IAM principals must have the account:PutAccountName IAM
permission.
Modifies the specified alternate contact attached to an Amazon Web Services account.
For complete details about how to use the alternate contact operations, see Update the alternate contacts for your Amazon Web Services account.
Before you can update the alternate contact information for an Amazon Web Services account that is managed by Organizations, you must first enable integration between Amazon Web Services Account Management and Organizations. For more information, see Enable trusted access for Amazon Web Services Account Management.
Updates the primary contact information of an Amazon Web Services account.
For complete details about how to use the primary contact operations, see Update the primary contact for your Amazon Web Services account.
Starts the process to update the primary email address for the specified account.