View Source AWS.Braket (aws-elixir v1.0.11)
The Amazon Braket API Reference provides information about the operations and structures supported by Amazon Braket.
To learn about the permissions required to call an Amazon Braket API action, see Actions, resources, and condition keys for Amazon Braket. Amazon Braket Python SDK and the AWS Command Line Interface can be used to make discovery and creation of API calls easier. For more information about Amazon Braket features, see What is Amazon Braket? and important terms and concepts in the Amazon Braket Developer Guide.
in-this-guide
In this guide:
*
*
CommonParametersCommonErrors
available-languages-for-aws-sdk
Available languages for AWS SDK:
* Ruby
code-examples-from-the-amazon-braket-tutorials-github-repository
Code examples from the Amazon Braket Tutorials GitHub repository:
Link to this section Summary
Functions
Cancels an Amazon Braket hybrid job.
Cancels the specified task.
Creates an Amazon Braket hybrid job.
Creates a quantum task.
Creates a spending limit for a specified quantum device.
Deletes an existing spending limit.
Retrieves the devices available in Amazon Braket.
Retrieves the specified Amazon Braket hybrid job.
Retrieves the specified quantum task.
Shows the tags associated with this resource.
Searches for devices using the specified filters.
Searches for Amazon Braket hybrid jobs that match the specified filter values.
Searches for tasks that match the specified filter values.
Searches and lists spending limits based on specified filters.
Add a tag to the specified resource.
Remove tags from a resource.
Updates an existing spending limit.
Link to this section Functions
Cancels an Amazon Braket hybrid job.
cancel_quantum_task(client, quantum_task_arn, input, options \\ [])
View SourceCancels the specified task.
Creates an Amazon Braket hybrid job.
Creates a quantum task.
Creates a spending limit for a specified quantum device.
Spending limits help you control costs by setting maximum amounts that can be spent on quantum computing tasks within a specified time period. Simulators do not support spending limits.
delete_spending_limit(client, spending_limit_arn, input, options \\ [])
View SourceDeletes an existing spending limit.
This operation permanently removes the spending limit and cannot be undone. After deletion, the associated device becomes unrestricted for spending.
Retrieves the devices available in Amazon Braket.
For backwards compatibility with older versions of BraketSchemas, OpenQASM information is omitted from GetDevice API calls. To get this information the user-agent needs to present a recent version of the BraketSchemas (1.8.0 or later). The Braket SDK automatically reports this for you. If you do not see OpenQASM results in the GetDevice response when using a Braket SDK, you may need to set AWS_EXECUTION_ENV environment variable to configure user-agent. See the code examples provided below for how to do this for the AWS CLI, Boto3, and the Go, Java, and JavaScript/TypeScript SDKs.
get_job(client, job_arn, additional_attribute_names \\ nil, options \\ [])
View SourceRetrieves the specified Amazon Braket hybrid job.
get_quantum_task(client, quantum_task_arn, additional_attribute_names \\ nil, options \\ [])
View SourceRetrieves the specified quantum task.
Shows the tags associated with this resource.
Searches for devices using the specified filters.
Searches for Amazon Braket hybrid jobs that match the specified filter values.
Searches for tasks that match the specified filter values.
Searches and lists spending limits based on specified filters.
This operation supports pagination and allows filtering by various criteria to find specific spending limits. We recommend using pagination to ensure that the operation returns quickly and successfully.
Add a tag to the specified resource.
Remove tags from a resource.
update_spending_limit(client, spending_limit_arn, input, options \\ [])
View SourceUpdates an existing spending limit.
You can modify the spending amount or time period. Changes take effect immediately.