View Source AWS.ConnectHealth (aws-elixir v1.0.11)

Health Agent for healthcare providers and patient engagement

Link to this section Summary

Functions

Activates a Subscription to enable billing for a user.

Creates a new Domain for managing HealthAgent resources.

Creates a new Subscription within a Domain for billing and user management.

Deactivates a Subscription to stop billing for a user.

Deletes a Domain and all associated resources.

Retrieves information about a Domain.

Retrieves details about an existing Medical Scribe listening session

Get details of a started patient insights job.

Retrieves information about a Subscription.

Lists the tags associated with the specified resource

Starts a new Medical Scribe listening session for real-time audio transcription

Associates the specified tags with the specified resource

Removes the specified tags from the specified resource

Link to this section Functions

Link to this function

activate_subscription(client, domain_id, subscription_id, input, options \\ [])

Activates a Subscription to enable billing for a user.

Link to this function

create_domain(client, input, options \\ [])

Creates a new Domain for managing HealthAgent resources.

Link to this function

create_subscription(client, domain_id, input, options \\ [])

Creates a new Subscription within a Domain for billing and user management.

Link to this function

deactivate_subscription(client, domain_id, subscription_id, input, options \\ [])

Deactivates a Subscription to stop billing for a user.

Link to this function

delete_domain(client, domain_id, input, options \\ [])

Deletes a Domain and all associated resources.

Link to this function

get_domain(client, domain_id, options \\ [])

Retrieves information about a Domain.

Link to this function

get_medical_scribe_listening_session(client, domain_id, session_id, subscription_id, options \\ [])

Retrieves details about an existing Medical Scribe listening session

Link to this function

get_patient_insights_job(client, domain_id, job_id, options \\ [])

Get details of a started patient insights job.

Link to this function

get_subscription(client, domain_id, subscription_id, options \\ [])

Retrieves information about a Subscription.

Link to this function

list_domains(client, max_results \\ nil, next_token \\ nil, status \\ nil, options \\ [])

Lists Domains for a given account.

Link to this function

list_subscriptions(client, domain_id, max_results \\ nil, next_token \\ nil, options \\ [])

Lists all Subscriptions within a Domain.

Link to this function

list_tags_for_resource(client, resource_arn, options \\ [])

Lists the tags associated with the specified resource

Link to this function

start_medical_scribe_listening_session(client, input, options \\ [])

Starts a new Medical Scribe listening session for real-time audio transcription

Link to this function

start_patient_insights_job(client, domain_id, input, options \\ [])

Starts a new patient insights job.

Link to this function

tag_resource(client, resource_arn, input, options \\ [])

Associates the specified tags with the specified resource

Link to this function

untag_resource(client, resource_arn, input, options \\ [])

Removes the specified tags from the specified resource