View Source AWS.DevOpsAgent (aws-elixir v1.0.11)

AWS DevOps Agent is a frontier agent that resolves and proactively prevents incidents, continuously improving reliability and performance.

AWS DevOps Agent investigates incidents and identifies operational improvements as an experienced DevOps engineer.

The agent works by:

  • Learning your resources and their relationships.
  • Working with your observability tools, runbooks, code repositories, and CI/CD pipelines.
  • Correlating telemetry, code, and deployment data to understand relationships between your application resources.
  • Supporting applications in multicloud and hybrid environments.

Link to this section Summary

Functions

Adds a specific service association to an AgentSpace.

Creates a new AgentSpace with the specified name and description.

Creates a new backlog task in the specified agent space

Creates a new chat execution in the specified agent space

Creates a Private Connection to a target resource.

Retrieves details of an existing Private Connection.

Disable the Operator App for the specified AgentSpace

Deletes a specific service association from an AgentSpace.

Enable the Operator App to access the given AgentSpace

Retrieves monthly account usage metrics and limits for the AWS account.

Retrieves detailed information about a specific AgentSpace.

Retrieves given associations configured for a specific AgentSpace.

Gets a backlog task for the specified agent space and task id

Get the full auth configuration of operator including any enabled auth flow

Retrieves given service by it's unique identifier

Lists all AgentSpaces with optional pagination.

List all associations for given AgentSpace

Lists backlog tasks in the specified agent space with optional filtering and sorting

Lists goals in the specified agent space with optional filtering

List journal records for a specific execution

List pending messages for a specific execution.

Lists all Private Connections in the caller's account.

Lists recommendations for the specified agent space

List a list of registered service on the account level.

Lists tags for the specified AWS DevOps Agent resource.

This operation registers the specified service

Sends a chat message and streams the response for the specified agent space execution

Adds or overwrites tags for the specified AWS DevOps Agent resource.

Removes tags from the specified AWS DevOps Agent resource.

Updates the information of an existing AgentSpace.

Partially updates the configuration of an existing service association for an AgentSpace.

Update the external Identity Provider configuration for the Operator App

Updates the certificate associated with a Private Connection.

Updates an existing recommendation with new content, status, or metadata

Validates an aws association and set status and returns a 204 No Content response on success.

Link to this section Functions

Link to this function

associate_service(client, agent_space_id, input, options \\ [])

Adds a specific service association to an AgentSpace.

It overwrites the existing association of the same service. Returns 201 Created on success.

Link to this function

create_agent_space(client, input, options \\ [])

Creates a new AgentSpace with the specified name and description.

Duplicate space names are allowed.

Link to this function

create_backlog_task(client, agent_space_id, input, options \\ [])

Creates a new backlog task in the specified agent space

Link to this function

create_chat(client, agent_space_id, input, options \\ [])

Creates a new chat execution in the specified agent space

Link to this function

create_private_connection(client, input, options \\ [])

Creates a Private Connection to a target resource.

Link to this function

delete_agent_space(client, agent_space_id, input, options \\ [])

Deletes an AgentSpace.

This operation is idempotent and returns a 204 No Content response on success.

Link to this function

delete_private_connection(client, name, input, options \\ [])

Deletes a Private Connection.

The deletion is asynchronous and returns DELETE_IN_PROGRESS status.

Link to this function

deregister_service(client, service_id, input, options \\ [])

Deregister a service

Link to this function

describe_private_connection(client, name, options \\ [])

Retrieves details of an existing Private Connection.

Link to this function

disable_operator_app(client, agent_space_id, input, options \\ [])

Disable the Operator App for the specified AgentSpace

Link to this function

disassociate_service(client, agent_space_id, association_id, input, options \\ [])

Deletes a specific service association from an AgentSpace.

This operation is idempotent and returns a 204 No Content response on success.

Link to this function

enable_operator_app(client, agent_space_id, input, options \\ [])

Enable the Operator App to access the given AgentSpace

Link to this function

get_account_usage(client, options \\ [])

Retrieves monthly account usage metrics and limits for the AWS account.

Link to this function

get_agent_space(client, agent_space_id, options \\ [])

Retrieves detailed information about a specific AgentSpace.

Link to this function

get_association(client, agent_space_id, association_id, options \\ [])

Retrieves given associations configured for a specific AgentSpace.

Link to this function

get_backlog_task(client, agent_space_id, task_id, options \\ [])

Gets a backlog task for the specified agent space and task id

Link to this function

get_operator_app(client, agent_space_id, options \\ [])

Get the full auth configuration of operator including any enabled auth flow

Link to this function

get_recommendation(client, agent_space_id, recommendation_id, recommendation_version \\ nil, options \\ [])

Retrieves a specific recommendation by its ID

Link to this function

get_service(client, service_id, options \\ [])

Retrieves given service by it's unique identifier

Link to this function

list_agent_spaces(client, input, options \\ [])

Lists all AgentSpaces with optional pagination.

Link to this function

list_associations(client, agent_space_id, input, options \\ [])

List all associations for given AgentSpace

Link to this function

list_backlog_tasks(client, agent_space_id, input, options \\ [])

Lists backlog tasks in the specified agent space with optional filtering and sorting

Link to this function

list_chats(client, agent_space_id, max_results \\ nil, next_token \\ nil, user_id \\ nil, options \\ [])

Retrieves a paginated list of the user's recent chat executions

Link to this function

list_executions(client, agent_space_id, input, options \\ [])

List executions

Link to this function

list_goals(client, agent_space_id, input, options \\ [])

Lists goals in the specified agent space with optional filtering

Link to this function

list_journal_records(client, agent_space_id, input, options \\ [])

List journal records for a specific execution

Link to this function

list_pending_messages(client, agent_space_id, input, options \\ [])

List pending messages for a specific execution.

Link to this function

list_private_connections(client, options \\ [])

Lists all Private Connections in the caller's account.

Link to this function

list_recommendations(client, agent_space_id, input, options \\ [])

Lists recommendations for the specified agent space

Link to this function

list_services(client, input, options \\ [])

List a list of registered service on the account level.

Link to this function

list_tags_for_resource(client, resource_arn, options \\ [])

Lists tags for the specified AWS DevOps Agent resource.

Link to this function

list_webhooks(client, agent_space_id, association_id, input, options \\ [])

List all webhooks for given Association

Link to this function

register_service(client, service, input, options \\ [])

This operation registers the specified service

Link to this function

send_message(client, agent_space_id, input, options \\ [])

Sends a chat message and streams the response for the specified agent space execution

Link to this function

tag_resource(client, resource_arn, input, options \\ [])

Adds or overwrites tags for the specified AWS DevOps Agent resource.

Link to this function

untag_resource(client, resource_arn, input, options \\ [])

Removes tags from the specified AWS DevOps Agent resource.

Link to this function

update_agent_space(client, agent_space_id, input, options \\ [])

Updates the information of an existing AgentSpace.

Link to this function

update_association(client, agent_space_id, association_id, input, options \\ [])

Partially updates the configuration of an existing service association for an AgentSpace.

Present fields are fully replaced; absent fields are left unchanged. Returns 200 OK on success.

Link to this function

update_backlog_task(client, agent_space_id, task_id, input, options \\ [])

Update an existing backlog task.

Link to this function

update_goal(client, agent_space_id, goal_id, input, options \\ [])

Update an existing goal

Link to this function

update_operator_app_idp_config(client, agent_space_id, input, options \\ [])

Update the external Identity Provider configuration for the Operator App

Link to this function

update_private_connection_certificate(client, name, input, options \\ [])

Updates the certificate associated with a Private Connection.

Link to this function

update_recommendation(client, agent_space_id, recommendation_id, input, options \\ [])

Updates an existing recommendation with new content, status, or metadata

Link to this function

validate_aws_associations(client, agent_space_id, input, options \\ [])

Validates an aws association and set status and returns a 204 No Content response on success.