View Source AWS.EMRServerless (aws-elixir v1.0.11)

Amazon EMR Serverless is a new deployment option for Amazon EMR.

Amazon EMR Serverless provides a serverless runtime environment that simplifies running analytics applications using the latest open source frameworks such as Apache Spark and Apache Hive. With Amazon EMR Serverless, you don’t have to configure, optimize, secure, or operate clusters to run applications with these frameworks.

The API reference to Amazon EMR Serverless is emr-serverless. The emr-serverless prefix is used in the following scenarios:

  • It is the prefix in the CLI commands for Amazon EMR Serverless. For example, aws emr-serverless start-job-run.

  • It is the prefix before IAM policy actions for Amazon EMR Serverless. For example, "Action": ["emr-serverless:StartJobRun"]. For more information, see Policy actions for Amazon EMR Serverless.

  • It is the prefix used in Amazon EMR Serverless service endpoints. For example, emr-serverless.us-east-2.amazonaws.com.

Link to this section Summary

Functions

Displays detailed information about a specified application.

Creates and returns a URL that you can use to access the application UIs for a job run.

Returns a URL that you can use to access the application UIs for a specified resource, such as a session.

Displays detailed information about a session.

Returns the session endpoint URL and a time-limited authentication token for the specified session.

Lists the tags assigned to the resources.

Starts a specified application and initializes initial capacity if configured.

Creates and starts a new session on the specified application.

Stops a specified application and releases initial capacity if configured.

Link to this section Functions

Link to this function

cancel_job_run(client, application_id, job_run_id, input, options \\ [])

Cancels a job run.

Link to this function

create_application(client, input, options \\ [])

Creates an application.

Link to this function

delete_application(client, application_id, input, options \\ [])

Deletes an application.

An application has to be in a stopped or created state in order to be deleted.

Link to this function

get_application(client, application_id, options \\ [])

Displays detailed information about a specified application.

Link to this function

get_dashboard_for_job_run(client, application_id, job_run_id, access_system_profile_logs \\ nil, attempt \\ nil, options \\ [])

Creates and returns a URL that you can use to access the application UIs for a job run.

For jobs in a running state, the application UI is a live user interface such as the Spark or Tez web UI. For completed jobs, the application UI is a persistent application user interface such as the Spark History Server or persistent Tez UI.

The URL is valid for one hour after you generate it. To access the application UI after that hour elapses, you must invoke the API again to generate a new URL.

Link to this function

get_job_run(client, application_id, job_run_id, attempt \\ nil, options \\ [])

Displays detailed information about a job run.

Link to this function

get_resource_dashboard(client, application_id, resource_id, resource_type, options \\ [])

Returns a URL that you can use to access the application UIs for a specified resource, such as a session.

For resources in a running state, the application UI is a live user interface such as the Spark web UI. For terminated resources, the application UI is a persistent application user interface such as the Spark History Server.

The URL is valid for one hour after you generate it. To access the application UI after that hour elapses, you must invoke the API again to generate a new URL.

Link to this function

get_session(client, application_id, session_id, options \\ [])

Displays detailed information about a session.

Link to this function

get_session_endpoint(client, application_id, session_id, options \\ [])

Returns the session endpoint URL and a time-limited authentication token for the specified session.

Use the endpoint and token to connect a client to the session. Call this operation again when the authentication token expires to obtain a new token.

Link to this function

list_applications(client, max_results \\ nil, next_token \\ nil, states \\ nil, options \\ [])

Lists applications based on a set of parameters.

Link to this function

list_job_run_attempts(client, application_id, job_run_id, max_results \\ nil, next_token \\ nil, options \\ [])

Lists all attempt of a job run.

Link to this function

list_job_runs(client, application_id, created_at_after \\ nil, created_at_before \\ nil, max_results \\ nil, mode \\ nil, next_token \\ nil, states \\ nil, options \\ [])

Lists job runs based on a set of parameters.

Link to this function

list_sessions(client, application_id, created_at_after \\ nil, created_at_before \\ nil, max_results \\ nil, next_token \\ nil, states \\ nil, options \\ [])

Lists sessions for the specified application.

You can filter sessions by state and creation time.

Link to this function

list_tags_for_resource(client, resource_arn, options \\ [])

Lists the tags assigned to the resources.

Link to this function

start_application(client, application_id, input, options \\ [])

Starts a specified application and initializes initial capacity if configured.

Link to this function

start_job_run(client, application_id, input, options \\ [])

Starts a job run.

Link to this function

start_session(client, application_id, input, options \\ [])

Creates and starts a new session on the specified application.

The application must be in the STARTED state or have AutoStart enabled, and have interactive sessions enabled. This operation is supported for EMR release 7.13.0 and later.

Link to this function

stop_application(client, application_id, input, options \\ [])

Stops a specified application and releases initial capacity if configured.

All scheduled and running jobs must be completed or cancelled before stopping an application.

Link to this function

tag_resource(client, resource_arn, input, options \\ [])

Assigns tags to resources.

A tag is a label that you assign to an Amazon Web Services resource. Each tag consists of a key and an optional value, both of which you define. Tags enable you to categorize your Amazon Web Services resources by attributes such as purpose, owner, or environment. When you have many resources of the same type, you can quickly identify a specific resource based on the tags you've assigned to it.

Link to this function

terminate_session(client, application_id, session_id, input, options \\ [])

Terminates the specified session.

After you terminate a session, it enters the TERMINATING state and then the TERMINATED state. You can still access the Spark History Server for a terminated session through the GetResourceDashboard operation.

Link to this function

untag_resource(client, resource_arn, input, options \\ [])

Removes tags from resources.

Link to this function

update_application(client, application_id, input, options \\ [])

Updates a specified application.

An application has to be in a stopped or created state in order to be updated.