View Source AWS.ElementalInference (aws-elixir v1.0.11)

This is the AWS Elemental Inference REST API Reference.

It provides information on the URL, request contents, and response contents of each AWS Elemental Inference REST operation.

We assume that you have the IAM permissions that you need to use AWS Elemental Inference via the REST API. We also assume that you are familiar with the features and operations of AWS Elemental Inference as described in AWS Elemental Inference User Guide.

Link to this section Summary

Functions

Associates a resource with the feed.

Deletes the specified feed.

Releases the resource (for example, an MediaLive channel) that is associated with this feed.

Retrieves information about the specified feed.

Displays a list of feeds that belong to this AWS account.

List all tags that are on an Elemental Inference resource in the current region.

Associates the specified tags to the resource identified by the specified resourceArn in the current region.

Deletes specified tags from the specified resource in the current region.

Updates the name and/or outputs in a feed.

Link to this section Functions

Link to this function

associate_feed(client, id, input, options \\ [])

Associates a resource with the feed.

The resource provides the input that Elemental Inference needs needs in order to perform an Elemental Inference feature, such as cropping video. You always provide the resource by associating it with a feed. You can associate only one resource with each feed.

Link to this function

create_feed(client, input, options \\ [])

Creates a feed.

The feed is the target for live streams being sent by the calling application. An example of a calling application is AWS Elemental MediaLive. After you create the feed, you can associate a resource with the feed.

Link to this function

delete_feed(client, id, input, options \\ [])

Deletes the specified feed.

The feed can be deleted at any time.

Link to this function

disassociate_feed(client, id, input, options \\ [])

Releases the resource (for example, an MediaLive channel) that is associated with this feed.

The outputs in the feed become disabled.

Link to this function

get_feed(client, id, options \\ [])

Retrieves information about the specified feed.

Link to this function

list_feeds(client, max_results \\ nil, next_token \\ nil, options \\ [])

Displays a list of feeds that belong to this AWS account.

Link to this function

list_tags_for_resource(client, resource_arn, options \\ [])

List all tags that are on an Elemental Inference resource in the current region.

Link to this function

tag_resource(client, resource_arn, input, options \\ [])

Associates the specified tags to the resource identified by the specified resourceArn in the current region.

If existing tags on a resource are not specified in the request parameters, they are not changed. When a resource is deleted, the tags associated with that resource are also deleted.

Link to this function

untag_resource(client, resource_arn, input, options \\ [])

Deletes specified tags from the specified resource in the current region.

Link to this function

update_feed(client, id, input, options \\ [])

Updates the name and/or outputs in a feed.