View Source AWS.GeoRoutes (aws-elixir v1.0.11)
With the Amazon Location Routes API you can calculate routes and estimate travel time based on up-to-date road network and live traffic information.
Calculate optimal travel routes and estimate travel times using up-to-date road network and traffic data. Key features include:
Point-to-point routing with estimated travel time, distance, and turn-by-turn directions
Multi-point route optimization to minimize travel time or distance
Route matrices for efficient multi-destination planning
Isoline calculations to determine reachable areas within specified time or distance thresholds
Map-matching to align GPS traces with the road network
Link to this section Summary
Functions
Calculates areas that can be reached within specified time or distance thresholds from a given point.
Use CalculateRouteMatrix to compute results for all pairs of Origins to
Destinations.
CalculateRoutes computes routes given the following required parameters:
Origin and Destination.
OptimizeWaypoints calculates the optimal order to travel between a set of
waypoints to minimize either the travel time or the distance travelled during
the journey, based on road network restrictions and the traffic pattern data.
SnapToRoads matches GPS trace to roads most likely traveled on.
Link to this section Functions
Calculates areas that can be reached within specified time or distance thresholds from a given point.
For example, you can use this operation to determine the area within a 30-minute drive of a store location, find neighborhoods within walking distance of a school, or identify delivery zones based on drive time.
Isolines (also known as isochrones for time-based calculations) are useful for various applications including:
Service area visualization - Show customers the area you can serve within promised delivery times
Site selection - Analyze potential business locations based on population within travel distance
Site selection - Determine areas that can be reached within specified response times
Route preferences such as avoiding toll roads or ferries are treated as preferences rather than absolute restrictions. If a viable route cannot be calculated while honoring all preferences, some may be ignored.
For more information, see Calculate isolines in the Amazon Location Service Developer Guide.
Use CalculateRouteMatrix to compute results for all pairs of Origins to
Destinations.
Each row corresponds to one entry in Origins. Each entry in the row corresponds to the route from that entry in Origins to an entry in Destinations positions.
For more information, see Calculate route matrix in the Amazon Location Service Developer Guide.
CalculateRoutes computes routes given the following required parameters:
Origin and Destination.
For more information, see Calculate routes in the Amazon Location Service Developer Guide.
OptimizeWaypoints calculates the optimal order to travel between a set of
waypoints to minimize either the travel time or the distance travelled during
the journey, based on road network restrictions and the traffic pattern data.
For more information, see Optimize waypoints in the Amazon Location Service Developer Guide.
SnapToRoads matches GPS trace to roads most likely traveled on.
For more information, see Snap to Roads in the Amazon Location Service Developer Guide.