View Source AWS.GroundStation (aws-elixir v1.0.11)
Welcome to the AWS Ground Station API Reference.
AWS Ground Station is a fully managed service that enables you to control satellite communications, downlink and process satellite data, and scale your satellite operations efficiently and cost-effectively without having to build or manage your own ground station infrastructure.
Link to this section Summary
Functions
Cancels or stops a contact with a specified contact ID based on its position in the contact lifecycle.
Creates a Config with the specified configData parameters.
Creates a DataflowEndpoint group containing the specified list of DataflowEndpoint objects.
Creates a DataflowEndpoint group containing the specified list of Ground
Station Agent based endpoints.
Create an ephemeris with your specified EphemerisData.
Creates a mission profile.
Deletes a dataflow endpoint group.
Delete an ephemeris.
Deletes a mission profile.
Describes an existing contact.
Describes a specific version of a contact.
Retrieve information about an existing ephemeris.
For use by AWS Ground Station Agent and shouldn't be called directly.
For use by AWS Ground Station Agent and shouldn't be called directly.
Returns Config information.
Returns the dataflow endpoint group.
Returns the number of reserved minutes used by account.
Returns a mission profile.
Returns a satellite.
Returns a list of antennas at a specified ground station.
Returns a list of Config objects.
Returns a list of versions for a specified contact.
Returns a list of contacts.
Returns a list of DataflowEndpoint groups.
List your existing ephemerides.
Returns a list of reservations for a specified ground station.
Returns a list of ground stations.
Returns a list of mission profiles.
Returns a list of satellites.
Returns a list of tags for a specified resource.
For use by AWS Ground Station Agent and shouldn't be called directly.
Reserves a contact using specified parameters.
Assigns a tag to a resource.
Deassigns a resource tag.
For use by AWS Ground Station Agent and shouldn't be called directly.
Updates the Config used when scheduling contacts.
Updates a specific contact.
Update an existing ephemeris.
Updates a mission profile.
Link to this section Functions
Cancels or stops a contact with a specified contact ID based on its position in the contact lifecycle.
For contacts that:
Have yet to start, the contact will be cancelled.
Have started but have yet to finish, the contact will be stopped.
Creates a Config with the specified configData parameters.
Only one type of configData can be specified.
Creates a DataflowEndpoint group containing the specified list of DataflowEndpoint objects.
The name field in each endpoint is used in your mission profile DataflowEndpointConfig to specify which endpoints to use during a contact.
When a contact uses multiple DataflowEndpointConfig objects, each Config
must match a DataflowEndpoint in the same group.
Creates a DataflowEndpoint group containing the specified list of Ground
Station Agent based endpoints.
The name field in each endpoint is used in your mission profile DataflowEndpointConfig to specify which endpoints to use during a contact.
When a contact uses multiple DataflowEndpointConfig objects, each Config
must match a DataflowEndpoint in the same group.
Create an ephemeris with your specified EphemerisData.
Creates a mission profile.
dataflowEdges is a list of lists of strings. Each lower level list of strings
has two elements: a from ARN and a to ARN.
delete_config(client, config_id, config_type, input, options \\ [])
View SourceDeletes a Config.
delete_dataflow_endpoint_group(client, dataflow_endpoint_group_id, input, options \\ [])
View SourceDeletes a dataflow endpoint group.
Delete an ephemeris.
delete_mission_profile(client, mission_profile_id, input, options \\ [])
View SourceDeletes a mission profile.
Describes an existing contact.
describe_contact_version(client, contact_id, version_id, options \\ [])
View SourceDescribes a specific version of a contact.
Retrieve information about an existing ephemeris.
For use by AWS Ground Station Agent and shouldn't be called directly.
Gets the latest configuration information for a registered agent.
get_agent_task_response_url(client, agent_id, task_id, options \\ [])
View SourceFor use by AWS Ground Station Agent and shouldn't be called directly.
Gets a presigned URL for uploading agent task response logs.
Returns Config information.
Only one Config response can be returned.
get_dataflow_endpoint_group(client, dataflow_endpoint_group_id, options \\ [])
View SourceReturns the dataflow endpoint group.
Returns the number of reserved minutes used by account.
Returns a mission profile.
Returns a satellite.
list_antennas(client, ground_station_id, max_results \\ nil, next_token \\ nil, options \\ [])
View SourceReturns a list of antennas at a specified ground station.
list_configs(client, max_results \\ nil, next_token \\ nil, options \\ [])
View SourceReturns a list of Config objects.
list_contact_versions(client, contact_id, max_results \\ nil, next_token \\ nil, options \\ [])
View SourceReturns a list of versions for a specified contact.
Returns a list of contacts.
If statusList contains AVAILABLE, the request must include groundStation,
missionprofileArn, and satelliteArn.
list_dataflow_endpoint_groups(client, max_results \\ nil, next_token \\ nil, options \\ [])
View SourceReturns a list of DataflowEndpoint groups.
List your existing ephemerides.
list_ground_station_reservations(client, ground_station_id, end_time, max_results \\ nil, next_token \\ nil, reservation_types \\ nil, start_time, options \\ [])
View SourceReturns a list of reservations for a specified ground station.
list_ground_stations(client, max_results \\ nil, next_token \\ nil, satellite_id \\ nil, options \\ [])
View SourceReturns a list of ground stations.
list_mission_profiles(client, max_results \\ nil, next_token \\ nil, options \\ [])
View SourceReturns a list of mission profiles.
list_satellites(client, max_results \\ nil, next_token \\ nil, options \\ [])
View SourceReturns a list of satellites.
Returns a list of tags for a specified resource.
For use by AWS Ground Station Agent and shouldn't be called directly.
Registers a new agent with AWS Ground Station.
Reserves a contact using specified parameters.
Assigns a tag to a resource.
Deassigns a resource tag.
For use by AWS Ground Station Agent and shouldn't be called directly.
Update the status of the agent.
update_config(client, config_id, config_type, input, options \\ [])
View SourceUpdates the Config used when scheduling contacts.
Updating a Config will not update the execution parameters for existing future
contacts scheduled with this Config.
Updates a specific contact.
Update an existing ephemeris.
update_mission_profile(client, mission_profile_id, input, options \\ [])
View SourceUpdates a mission profile.
Updating a mission profile will not update the execution parameters for existing future contacts.