View Source AWS.InspectorScan (aws-elixir v1.0.11)

Amazon Inspector Scan is a vulnerability discovery service that scans a provided Software Bill of Materials (SBOM) for security vulnerabilities.

Link to this section Summary

Functions

Scans a provided CycloneDX 1.5 SBOM and reports on any vulnerabilities discovered in that SBOM.

Link to this section Functions

Link to this function

scan_sbom(client, input, options \\ [])

Scans a provided CycloneDX 1.5 SBOM and reports on any vulnerabilities discovered in that SBOM.

You can generate compatible SBOMs for your resources using the Amazon Inspector SBOM generator.

The output of this action reports NVD and CVSS scores when NVD and CVSS scores are available. Because the output reports both scores, you might notice a discrepency between them. However, you can triage the severity of either score depending on the vendor of your choosing.