View Source AWS.Invoicing (aws-elixir v1.0.11)

amazon-web-services-invoice-configuration

Amazon Web Services Invoice Configuration

You can use Amazon Web Services Invoice Configuration APIs to programmatically create, update, delete, get, and list invoice units.

You can also programmatically fetch the information of the invoice receiver. For example, business legal name, address, and invoicing contacts.

You can use Amazon Web Services Invoice Configuration to receive separate Amazon Web Services invoices based your organizational needs. By using Amazon Web Services Invoice Configuration, you can configure invoice units that are groups of Amazon Web Services accounts that represent your business entities, and receive separate invoices for each business entity. You can also assign a unique member or payer account as the invoice receiver for each invoice unit. As you create new accounts within your Organizations using Amazon Web Services Invoice Configuration APIs, you can automate the creation of new invoice units and subsequently automate the addition of new accounts to your invoice units.

amazon-web-services-procurement-portal-preferences

Amazon Web Services Procurement Portal Preferences

You can use Amazon Web Services Procurement Portal Preferences APIs to programmatically create, update, delete, get, and list procurement portal connections and e-invoice delivery settings. You can also programmatically fetch and modify the status of procurement portal configurations. For example, SAP Business Network or Coupa connections, configure e-invoice delivery and purchase order retrieval features.

You can use Amazon Web Services Procurement Portal Preferences to connect e-invoice delivery to your procurement portals based on your organizational needs. By using Amazon Web Services Procurement Portal Preferences, you can configure connections to SAP Business Network and Coupa procurement portals that retrieve purchase orders and deliver Amazon Web Services invoices on the same day they are generated. You can also set up testing environments to validate invoice delivery without affecting live transactions, and manage contact information for portal setup and support.

Administrative users should understand that billing read-only policies will show all procurement portal connection details. Review your IAM policies to ensure appropriate access controls are in place for procurement portal preferences.

amazon-web-services-invoice-management

Amazon Web Services Invoice Management

You can use Amazon Web Services Invoice Management APIs to programmatically list invoice summaries and get invoice documents. You can also programmatically fetch invoice documents with S3 pre-signed URLs.

You can use Amazon Web Services Invoice Management to access invoice information based on your organizational needs. By using Amazon Web Services Invoice Management, you can retrieve paginated lists of invoice summaries that include invoice metadata such as invoice IDs, amounts, and currencies without downloading documents. You can also download invoice documents in PDF format using S3 pre-signed URLs with built-in expiration. As you manage invoices across your organization using Amazon Web Services Invoice Management APIs, you can create invoice retrieval processes and integrate invoice data into your financial systems.

Service endpoint

You can use the following endpoints for Amazon Web Services Invoice Configuration, Amazon Web Services Procurement Portal Preferences, and Amazon Web Services Invoice Management:

  • https://invoicing.us-east-1.api.aws

Link to this section Summary

Functions

This gets the invoice profile associated with a set of accounts.

This creates a new invoice unit with the provided definition.

  • **This feature API is subject to changing at any time.

For more information, see the Amazon Web Services Service Terms (Betas and Previews).*

This deletes an invoice unit with the provided invoice unit ARN.

  • **This feature API is subject to changing at any time.

For more information, see the Amazon Web Services Service Terms (Betas and Previews).*

Returns a URL to download the invoice document and supplemental documents associated with an invoice.

This retrieves the invoice unit definition.

  • **This feature API is subject to changing at any time.

For more information, see the Amazon Web Services Service Terms (Betas and Previews).*

Retrieves your invoice details programmatically, without line item details.

This fetches a list of all invoice unit definitions for a given account, as of the provided AsOf date.

  • **This feature API is subject to changing at any time.

For more information, see the Amazon Web Services Service Terms (Betas and Previews).*

  • **This feature API is subject to changing at any time.

For more information, see the Amazon Web Services Service Terms (Betas and Previews).*

Adds a tag to a resource.

Removes a tag from a resource.

You can update the invoice unit configuration at any time, and Amazon Web Services will use the latest configuration at the end of the month.

  • **This feature API is subject to changing at any time.

For more information, see the Amazon Web Services Service Terms (Betas and Previews).*

Link to this section Functions

Link to this function

batch_get_invoice_profile(client, input, options \\ [])

This gets the invoice profile associated with a set of accounts.

The accounts must be linked accounts under the requester management account organization.

Link to this function

create_invoice_unit(client, input, options \\ [])

This creates a new invoice unit with the provided definition.

Link to this function

create_procurement_portal_preference(client, input, options \\ [])

  • **This feature API is subject to changing at any time.

For more information, see the Amazon Web Services Service Terms (Betas and Previews).*

Creates a procurement portal preference configuration for e-invoice delivery and purchase order retrieval. This preference defines how invoices are delivered to a procurement portal and how purchase orders are retrieved.

Link to this function

delete_invoice_unit(client, input, options \\ [])

This deletes an invoice unit with the provided invoice unit ARN.

Link to this function

delete_procurement_portal_preference(client, input, options \\ [])

  • **This feature API is subject to changing at any time.

For more information, see the Amazon Web Services Service Terms (Betas and Previews).*

Deletes an existing procurement portal preference. This action cannot be undone. Active e-invoice delivery and PO retrieval configurations will be terminated.

Link to this function

get_invoice_p_d_f(client, input, options \\ [])

Returns a URL to download the invoice document and supplemental documents associated with an invoice.

The URLs are pre-signed and have expiration time. For special cases like Brazil, where Amazon Web Services generated invoice identifiers and government provided identifiers do not match, use the Amazon Web Services generated invoice identifier when making API requests. To grant IAM permission to use this operation, the caller needs the invoicing:GetInvoicePDF policy action.

Link to this function

get_invoice_unit(client, input, options \\ [])

This retrieves the invoice unit definition.

Link to this function

get_procurement_portal_preference(client, input, options \\ [])

  • **This feature API is subject to changing at any time.

For more information, see the Amazon Web Services Service Terms (Betas and Previews).*

Retrieves the details of a specific procurement portal preference configuration.

Link to this function

list_invoice_summaries(client, input, options \\ [])

Retrieves your invoice details programmatically, without line item details.

Link to this function

list_invoice_units(client, input, options \\ [])

This fetches a list of all invoice unit definitions for a given account, as of the provided AsOf date.

Link to this function

list_procurement_portal_preferences(client, input, options \\ [])

  • **This feature API is subject to changing at any time.

For more information, see the Amazon Web Services Service Terms (Betas and Previews).*

Retrieves a list of procurement portal preferences associated with the Amazon Web Services account.

Link to this function

list_tags_for_resource(client, input, options \\ [])

Lists the tags for a resource.

Link to this function

put_procurement_portal_preference(client, input, options \\ [])

  • **This feature API is subject to changing at any time.

For more information, see the Amazon Web Services Service Terms (Betas and Previews).*

Updates an existing procurement portal preference configuration. This operation can modify settings for e-invoice delivery and purchase order retrieval.

Link to this function

tag_resource(client, input, options \\ [])

Adds a tag to a resource.

Link to this function

untag_resource(client, input, options \\ [])

Removes a tag from a resource.

Link to this function

update_invoice_unit(client, input, options \\ [])

You can update the invoice unit configuration at any time, and Amazon Web Services will use the latest configuration at the end of the month.

Link to this function

update_procurement_portal_preference_status(client, input, options \\ [])

  • **This feature API is subject to changing at any time.

For more information, see the Amazon Web Services Service Terms (Betas and Previews).*

Updates the status of a procurement portal preference, including the activation state of e-invoice delivery and purchase order retrieval features.