View Source AWS.PartnerCentralChannel (aws-elixir v1.0.11)

AWS Partner Central Channel service for managing partner relationships, handshakes, and program management accounts.

Link to this section Summary

Functions

Accepts a pending channel handshake request from another AWS account.

Cancels a pending channel handshake request.

Creates a new channel handshake request to establish a partnership with another AWS account.

Creates a new program management account for managing partner relationships.

Creates a new partner relationship between accounts.

Deletes a partner relationship.

Retrieves details of a specific partner relationship.

Lists channel handshakes based on specified criteria.

Lists program management accounts based on specified criteria.

Lists partner relationships based on specified criteria.

Lists tags associated with a specific resource.

Rejects a pending channel handshake request.

Adds or updates tags for a specified resource.

Removes tags from a specified resource.

Updates the properties of a program management account.

Updates the properties of a partner relationship.

Link to this section Functions

Link to this function

accept_channel_handshake(client, input, options \\ [])

Accepts a pending channel handshake request from another AWS account.

Link to this function

cancel_channel_handshake(client, input, options \\ [])

Cancels a pending channel handshake request.

Link to this function

create_channel_handshake(client, input, options \\ [])

Creates a new channel handshake request to establish a partnership with another AWS account.

Link to this function

create_program_management_account(client, input, options \\ [])

Creates a new program management account for managing partner relationships.

Link to this function

create_relationship(client, input, options \\ [])

Creates a new partner relationship between accounts.

Link to this function

delete_program_management_account(client, input, options \\ [])

Deletes a program management account.

Link to this function

delete_relationship(client, input, options \\ [])

Deletes a partner relationship.

Link to this function

get_relationship(client, input, options \\ [])

Retrieves details of a specific partner relationship.

Link to this function

list_channel_handshakes(client, input, options \\ [])

Lists channel handshakes based on specified criteria.

Link to this function

list_program_management_accounts(client, input, options \\ [])

Lists program management accounts based on specified criteria.

Link to this function

list_relationships(client, input, options \\ [])

Lists partner relationships based on specified criteria.

Link to this function

list_tags_for_resource(client, input, options \\ [])

Lists tags associated with a specific resource.

Link to this function

reject_channel_handshake(client, input, options \\ [])

Rejects a pending channel handshake request.

Link to this function

tag_resource(client, input, options \\ [])

Adds or updates tags for a specified resource.

Link to this function

untag_resource(client, input, options \\ [])

Removes tags from a specified resource.

Link to this function

update_program_management_account(client, input, options \\ [])

Updates the properties of a program management account.

Link to this function

update_relationship(client, input, options \\ [])

Updates the properties of a partner relationship.