View Source AWS.Pricing (aws-elixir v1.0.11)
The Amazon Web Services Price List API is a centralized and convenient way to programmatically query Amazon Web Services for services, products, and pricing information.
The Amazon Web Services Price List uses standardized product attributes such as
Location, Storage Class, and Operating System, and provides prices at the
SKU level. You can use the Amazon Web Services Price List to do the following:
Build cost control and scenario planning tools
Reconcile billing data
Forecast future spend for budgeting purposes
Provide cost benefit analysis that compare your internal workloads with Amazon Web Services
Use GetServices without a service code to retrieve the service codes for all
Amazon Web Services services, then GetServices with a service code to retrieve
the attribute names for that service. After you have the service code and
attribute names, you can use GetAttributeValues to see what values are
available for an attribute. With the service code and an attribute name and
value, you can use GetProducts to find specific products that you're
interested in, such as an AmazonEC2 instance, with a Provisioned IOPS
volumeType.
For more information, see Using the Amazon Web Services Price List API in the Billing User Guide.
Link to this section Summary
Functions
Returns the metadata for one service or a list of the metadata for all services.
Returns a list of attribute values.
- **This feature is in preview release and is subject to change.
Your use of Amazon Web Services Price List API is subject to the Beta Service Participation terms of the Amazon Web Services Service Terms (Section 1.10).*
Returns a list of all products that match the filter criteria.
- **This feature is in preview release and is subject to change.
Your use of Amazon Web Services Price List API is subject to the Beta Service Participation terms of the Amazon Web Services Service Terms (Section 1.10).*
Link to this section Functions
Returns the metadata for one service or a list of the metadata for all services.
Use this without a service code to get the service codes for all services. Use
it with a service code, such as AmazonEC2, to get information specific to that
service, such as the attribute names available for that service. For example,
some of the attribute names available for EC2 are volumeType, maxIopsVolume,
operation, locationType, and instanceCapacity10xlarge.
Returns a list of attribute values.
Attributes are similar to the details in a Price List API offer file. For a list of available attributes, see Offer File Definitions in the Billing and Cost Management User Guide.
- **This feature is in preview release and is subject to change.
Your use of Amazon Web Services Price List API is subject to the Beta Service Participation terms of the Amazon Web Services Service Terms (Section 1.10).*
This returns the URL that you can retrieve your Price List file from. This URL
is based on the PriceListArn and FileFormat that you retrieve from the
ListPriceLists
response.
Returns a list of all products that match the filter criteria.
- **This feature is in preview release and is subject to change.
Your use of Amazon Web Services Price List API is subject to the Beta Service Participation terms of the Amazon Web Services Service Terms (Section 1.10).*
This returns a list of Price List references that the requester if authorized to
view, given a ServiceCode, CurrencyCode, and an EffectiveDate. Use without
a RegionCode filter to list Price List references from all available Amazon
Web Services Regions. Use with a RegionCode filter to get the Price List
reference that's specific to a specific Amazon Web Services Region. You can use
the PriceListArn from the response to get your preferred Price List files
through the
GetPriceListFileUrl
API.