View Source AWS.RedshiftServerless (aws-elixir v1.0.11)
This is an interface reference for Amazon Redshift Serverless.
It contains documentation for one of the programming or command line interfaces you can use to manage Amazon Redshift Serverless.
Amazon Redshift Serverless automatically provisions data warehouse capacity and intelligently scales the underlying resources based on workload demands. Amazon Redshift Serverless adjusts capacity in seconds to deliver consistently high performance and simplified operations for even the most demanding and volatile workloads. Amazon Redshift Serverless lets you focus on using your data to acquire new insights for your business and customers.
To learn more about Amazon Redshift Serverless, see What is Amazon Redshift Serverless?.
Link to this section Summary
Functions
Converts a recovery point to a snapshot.
Creates a custom domain association for Amazon Redshift Serverless.
Creates an Amazon Redshift Serverless managed VPC endpoint.
Creates a namespace in Amazon Redshift Serverless.
Creates an Amazon Redshift Serverless reservation, which gives you the option to commit to a specified number of Redshift Processing Units (RPUs) for a year at a discount from Serverless on-demand (OD) rates.
Creates a scheduled action.
Creates a snapshot of all databases in a namespace.
Creates a snapshot copy configuration that lets you copy snapshots to another Amazon Web Services Region.
Creates a usage limit for a specified Amazon Redshift Serverless usage type.
Creates an workgroup in Amazon Redshift Serverless.
Deletes a custom domain association for Amazon Redshift Serverless.
Deletes an Amazon Redshift Serverless managed VPC endpoint.
Deletes a namespace from Amazon Redshift Serverless.
Deletes the specified resource policy.
Deletes a scheduled action.
Deletes a snapshot from Amazon Redshift Serverless.
Deletes a snapshot copy configuration
Deletes a usage limit from Amazon Redshift Serverless.
Deletes a workgroup.
Returns a database user name and temporary password with temporary authorization to log in to Amazon Redshift Serverless.
Gets information about a specific custom domain association.
Returns information, such as the name, about a VPC endpoint.
Returns an Identity Center authentication token for accessing Amazon Redshift Serverless workgroups.
Returns information about a namespace in Amazon Redshift Serverless.
Returns information about a recovery point.
Gets an Amazon Redshift Serverless reservation.
Returns the reservation offering.
Returns a resource policy.
Returns information about a scheduled action.
Returns information about a specific snapshot.
Returns information about a TableRestoreStatus object.
Get the Redshift Serverless version for a specified track.
Returns information about a usage limit.
Returns information about a specific workgroup.
Lists custom domain associations for Amazon Redshift Serverless.
Returns an array of EndpointAccess objects and relevant information.
Returns information about a list of specified managed workgroups in your account.
Returns information about a list of specified namespaces.
Returns an array of recovery points.
Returns the current reservation offerings in your account.
Returns a list of Reservation objects.
Returns a list of scheduled actions.
Returns a list of snapshot copy configurations.
Returns a list of snapshots.
Returns information about an array of TableRestoreStatus objects.
Lists the tags assigned to a resource.
List the Amazon Redshift Serverless versions.
Lists all usage limits within Amazon Redshift Serverless.
Returns information about a list of specified workgroups.
Creates or updates a resource policy.
Restore the data from a recovery point.
Restores a namespace from a snapshot.
Restores a table from a recovery point to your Amazon Redshift Serverless instance.
Restores a table from a snapshot to your Amazon Redshift Serverless instance.
Assigns one or more tags to a resource.
Removes a tag or set of tags from a resource.
Updates an Amazon Redshift Serverless certificate associated with a custom domain.
Updates an Amazon Redshift Serverless managed endpoint.
Modifies the lakehouse configuration for a namespace.
Updates a namespace with the specified settings.
Updates a scheduled action.
Updates a snapshot.
Updates a snapshot copy configuration.
Update a usage limit in Amazon Redshift Serverless.
Updates a workgroup with the specified configuration settings.
Link to this section Functions
Converts a recovery point to a snapshot.
For more information about recovery points and snapshots, see Working with snapshots and recovery points.
Creates a custom domain association for Amazon Redshift Serverless.
Creates an Amazon Redshift Serverless managed VPC endpoint.
Creates a namespace in Amazon Redshift Serverless.
Creates an Amazon Redshift Serverless reservation, which gives you the option to commit to a specified number of Redshift Processing Units (RPUs) for a year at a discount from Serverless on-demand (OD) rates.
Creates a scheduled action.
A scheduled action contains a schedule and an Amazon Redshift API action. For
example, you can create a schedule of when to run the CreateSnapshot API
operation.
Creates a snapshot of all databases in a namespace.
For more information about snapshots, see Working with snapshots and recovery points.
Creates a snapshot copy configuration that lets you copy snapshots to another Amazon Web Services Region.
Creates a usage limit for a specified Amazon Redshift Serverless usage type.
The usage limit is identified by the returned usage limit identifier.
Creates an workgroup in Amazon Redshift Serverless.
VPC Block Public Access (BPA) enables you to block resources in VPCs and subnets that you own in a Region from reaching or being reached from the internet through internet gateways and egress-only internet gateways. If a workgroup is in an account with VPC BPA turned on, the following capabilities are blocked:
Creating a public access workgroup
Modifying a private workgroup to public
Adding a subnet with VPC BPA turned on to the workgroup when the workgroup is public
For more information about VPC BPA, see Block public access to VPCs and subnets in the Amazon VPC User Guide.
Deletes a custom domain association for Amazon Redshift Serverless.
Deletes an Amazon Redshift Serverless managed VPC endpoint.
Deletes a namespace from Amazon Redshift Serverless.
Before you delete the namespace, you can create a final snapshot that has all of the data within the namespace.
Deletes the specified resource policy.
Deletes a scheduled action.
Deletes a snapshot from Amazon Redshift Serverless.
Deletes a snapshot copy configuration
Deletes a usage limit from Amazon Redshift Serverless.
Deletes a workgroup.
Returns a database user name and temporary password with temporary authorization to log in to Amazon Redshift Serverless.
By default, the temporary credentials expire in 900 seconds. You can optionally specify a duration between 900 seconds (15 minutes) and 3600 seconds (60 minutes).
The Identity and Access Management (IAM) user or role that runs GetCredentials must have an IAM policy attached that allows access to all necessary actions and resources.
If the DbName parameter is specified, the IAM policy must allow access to the
resource dbname for the specified database name.
Gets information about a specific custom domain association.
Returns information, such as the name, about a VPC endpoint.
Returns an Identity Center authentication token for accessing Amazon Redshift Serverless workgroups.
The token provides secure access to data within the specified workgroups using Identity Center identity propagation. The token expires after a specified duration and must be refreshed for continued access.
The Identity and Access Management (IAM) user or role that runs GetIdentityCenterAuthToken must have appropriate permissions to access the specified workgroups and Identity Center integration must be configured for the workgroups.
Returns information about a namespace in Amazon Redshift Serverless.
Returns information about a recovery point.
Gets an Amazon Redshift Serverless reservation.
A reservation gives you the option to commit to a specified number of Redshift Processing Units (RPUs) for a year at a discount from Serverless on-demand (OD) rates.
Returns the reservation offering.
The offering determines the payment schedule for the reservation.
Returns a resource policy.
Returns information about a scheduled action.
Returns information about a specific snapshot.
Returns information about a TableRestoreStatus object.
Get the Redshift Serverless version for a specified track.
Returns information about a usage limit.
Returns information about a specific workgroup.
Lists custom domain associations for Amazon Redshift Serverless.
Returns an array of EndpointAccess objects and relevant information.
Returns information about a list of specified managed workgroups in your account.
Returns information about a list of specified namespaces.
Returns an array of recovery points.
Returns the current reservation offerings in your account.
Returns a list of Reservation objects.
Returns a list of scheduled actions.
You can use the flags to filter the list of returned scheduled actions.
Returns a list of snapshot copy configurations.
Returns a list of snapshots.
Returns information about an array of TableRestoreStatus objects.
Lists the tags assigned to a resource.
List the Amazon Redshift Serverless versions.
Lists all usage limits within Amazon Redshift Serverless.
Returns information about a list of specified workgroups.
Creates or updates a resource policy.
Currently, you can use policies to share snapshots across Amazon Web Services accounts.
Restore the data from a recovery point.
Restores a namespace from a snapshot.
Restores a table from a recovery point to your Amazon Redshift Serverless instance.
You can't use this operation to restore tables with interleaved sort keys.
Restores a table from a snapshot to your Amazon Redshift Serverless instance.
You can't use this operation to restore tables with interleaved sort keys.
Assigns one or more tags to a resource.
Removes a tag or set of tags from a resource.
Updates an Amazon Redshift Serverless certificate associated with a custom domain.
Updates an Amazon Redshift Serverless managed endpoint.
Modifies the lakehouse configuration for a namespace.
This operation allows you to manage Amazon Redshift federated permissions and Amazon Web Services IAM Identity Center trusted identity propagation.
Updates a namespace with the specified settings.
Unless required, you can't update multiple parameters in one request. For
example, you must specify both adminUsername and adminUserPassword to update
either field, but you can't update both kmsKeyId and logExports in a single
request.
Updates a scheduled action.
Updates a snapshot.
Updates a snapshot copy configuration.
Update a usage limit in Amazon Redshift Serverless.
You can't update the usage type or period of a usage limit.
Updates a workgroup with the specified configuration settings.
You can't update multiple parameters in one request. For example, you can update
baseCapacity or port in a single request, but you can't update both in the
same request.
VPC Block Public Access (BPA) enables you to block resources in VPCs and subnets that you own in a Region from reaching or being reached from the internet through internet gateways and egress-only internet gateways. If a workgroup is in an account with VPC BPA turned on, the following capabilities are blocked:
Creating a public access workgroup
Modifying a private workgroup to public
Adding a subnet with VPC BPA turned on to the workgroup when the workgroup is public
For more information about VPC BPA, see Block public access to VPCs and subnets in the Amazon VPC User Guide.