View Source AWS.Route53GlobalResolver (aws-elixir v1.0.11)

Amazon Route 53 Global Resolver is a global, internet-accessible DNS resolver that enables customers to resolve and forward traffic for both public and private domains while ensuring security and authenticity of queries over the internet.

Route 53 Global Resolver supports DNS-over-port 53 (Do53), DNS-over-TLS (DoT), and DNS-over-HTTPS (DoH) protocols through global anycast IP addresses.

Route 53 Global Resolver is a global service that supports resolvers in multiple Amazon Web Services Regions but you must specify the US East (Ohio) Region to create, update, or otherwise work with Route 53 Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.

Link to this section Summary

Functions

Associates a Route 53 private hosted zone with a Route 53 Global Resolver resource.

Creates multiple DNS firewall rules in a single operation.

Deletes multiple DNS firewall rules in a single operation.

Updates multiple DNS firewall rules in a single operation.

Creates an access source for a DNS view.

Creates an access token for a DNS view.

Creates a DNS view within a Route 53 Global Resolver.

Creates a new Route 53 Global Resolver instance.

Disables a DNS view, preventing it from serving DNS queries.

Disassociates a Route 53 private hosted zone from a Route 53 Global Resolver resource.

Enables a disabled DNS view, allowing it to serve DNS queries again.

Retrieves information about an access source.

Retrieves information about an access token.

Retrieves information about a DNS view.

Retrieves information about a firewall domain list.

Retrieves information about a DNS firewall rule.

Retrieves information about a Route 53 Global Resolver instance.

Retrieves information about a hosted zone association.

Retrieves information about an Amazon Web Services-managed firewall domain list.

Imports a list of domains from an Amazon S3 file into a firewall domain list.

Lists all DNS views for a Route 53 Global Resolver with pagination support.

Lists all firewall domain lists for a Route 53 Global Resolver with pagination support.

Lists all Route 53 Global Resolver instances in your account with pagination support.

Lists all hosted zone associations for a Route 53 Global Resolver resource with pagination support.

Returns a paginated list of the Amazon Web Services Managed DNS Lists and the categories for DNS Firewall.

Lists the tags associated with a Route 53 Global Resolver resource.

Adds or updates tags for a Route 53 Global Resolver resource.

Removes tags from a Route 53 Global Resolver resource.

Updates the configuration of an access source.

Updates the configuration of an access token.

Updates the configuration of a DNS view.

Updates a DNS Firewall domain list from an array of specified domains.

Updates the configuration of a DNS firewall rule.

Updates the configuration of a Route 53 Global Resolver instance.

Link to this section Functions

Link to this function

associate_hosted_zone(client, hosted_zone_id, input, options \\ [])

Associates a Route 53 private hosted zone with a Route 53 Global Resolver resource.

This allows the resolver to resolve DNS queries for the private hosted zone from anywhere globally.

Route 53 Global Resolver is a global service that supports resolvers in multiple Amazon Web Services Regions but you must specify the US East (Ohio) Region to create, update, or otherwise work with Route 53 Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.

Link to this function

batch_create_firewall_rule(client, input, options \\ [])

Creates multiple DNS firewall rules in a single operation.

This is more efficient than creating rules individually when you need to set up multiple rules at once.

Route 53 Global Resolver is a global service that supports resolvers in multiple Amazon Web Services Regions but you must specify the US East (Ohio) Region to create, update, or otherwise work with Route 53 Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.

Link to this function

batch_delete_firewall_rule(client, input, options \\ [])

Deletes multiple DNS firewall rules in a single operation.

This is more efficient than deleting rules individually.

Route 53 Global Resolver is a global service that supports resolvers in multiple Amazon Web Services Regions but you must specify the US East (Ohio) Region to create, update, or otherwise work with Route 53 Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.

Link to this function

batch_update_firewall_rule(client, input, options \\ [])

Updates multiple DNS firewall rules in a single operation.

This is more efficient than updating rules individually.

Route 53 Global Resolver is a global service that supports resolvers in multiple Amazon Web Services Regions but you must specify the US East (Ohio) Region to create, update, or otherwise work with Route 53 Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.

Link to this function

create_access_source(client, input, options \\ [])

Creates an access source for a DNS view.

Access sources define IP addresses or CIDR ranges that are allowed to send DNS queries to the Route 53 Global Resolver, along with the permitted DNS protocols.

Route 53 Global Resolver is a global service that supports resolvers in multiple Amazon Web Services Regions but you must specify the US East (Ohio) Region to create, update, or otherwise work with Route 53 Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.

Link to this function

create_access_token(client, dns_view_id, input, options \\ [])

Creates an access token for a DNS view.

Access tokens provide token-based authentication for DNS-over-HTTPS (DoH) and DNS-over-TLS (DoT) connections to the Route 53 Global Resolver.

Route 53 Global Resolver is a global service that supports resolvers in multiple Amazon Web Services Regions but you must specify the US East (Ohio) Region to create, update, or otherwise work with Route 53 Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.

Link to this function

create_dns_view(client, global_resolver_id, input, options \\ [])

Creates a DNS view within a Route 53 Global Resolver.

A DNS view models end users, user groups, networks, and devices, and serves as a parent resource that holds configurations controlling access, authorization, DNS firewall rules, and forwarding rules.

Route 53 Global Resolver is a global service that supports resolvers in multiple Amazon Web Services Regions but you must specify the US East (Ohio) Region to create, update, or otherwise work with Route 53 Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.

Link to this function

create_firewall_domain_list(client, global_resolver_id, input, options \\ [])

Creates a firewall domain list.

Domain lists are reusable sets of domain specifications that you use in DNS firewall rules to allow, block, or alert on DNS queries to specific domains.

Route 53 Global Resolver is a global service that supports resolvers in multiple Amazon Web Services Regions but you must specify the US East (Ohio) Region to create, update, or otherwise work with Route 53 Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.

Link to this function

create_firewall_rule(client, input, options \\ [])

Creates a DNS firewall rule.

Firewall rules define actions (ALLOW, BLOCK, or ALERT) to take on DNS queries that match specified domain lists, managed domain lists, or advanced threat protections.

Route 53 Global Resolver is a global service that supports resolvers in multiple Amazon Web Services Regions but you must specify the US East (Ohio) Region to create, update, or otherwise work with Route 53 Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.

Link to this function

create_global_resolver(client, input, options \\ [])

Creates a new Route 53 Global Resolver instance.

A Route 53 Global Resolver is a global, internet-accessible DNS resolver that provides secure DNS resolution for both public and private domains through global anycast IP addresses.

Route 53 Global Resolver is a global service that supports resolvers in multiple Amazon Web Services Regions but you must specify the US East (Ohio) Region to create, update, or otherwise work with Route 53 Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.

Link to this function

delete_access_source(client, access_source_id, input, options \\ [])

Deletes an access source.

This operation cannot be undone.

Route 53 Global Resolver is a global service that supports resolvers in multiple Amazon Web Services Regions but you must specify the US East (Ohio) Region to create, update, or otherwise work with Route 53 Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.

Link to this function

delete_access_token(client, access_token_id, input, options \\ [])

Deletes an access token.

This operation cannot be undone.

Route 53 Global Resolver is a global service that supports resolvers in multiple Amazon Web Services Regions but you must specify the US East (Ohio) Region to create, update, or otherwise work with Route 53 Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.

Link to this function

delete_dns_view(client, dns_view_id, input, options \\ [])

Deletes a DNS view.

This operation cannot be undone.

Route 53 Global Resolver is a global service that supports resolvers in multiple Amazon Web Services Regions but you must specify the US East (Ohio) Region to create, update, or otherwise work with Route 53 Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.

Link to this function

delete_firewall_domain_list(client, firewall_domain_list_id, input, options \\ [])

Deletes a firewall domain list.

This operation cannot be undone.

Route 53 Global Resolver is a global service that supports resolvers in multiple Amazon Web Services Regions but you must specify the US East (Ohio) Region to create, update, or otherwise work with Route 53 Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.

Link to this function

delete_firewall_rule(client, firewall_rule_id, input, options \\ [])

Deletes a DNS firewall rule.

This operation cannot be undone.

Route 53 Global Resolver is a global service that supports resolvers in multiple Amazon Web Services Regions but you must specify the US East (Ohio) Region to create, update, or otherwise work with Route 53 Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.

Link to this function

delete_global_resolver(client, global_resolver_id, input, options \\ [])

Deletes a Route 53 Global Resolver instance.

This operation cannot be undone. All associated DNS views, access sources, tokens, and firewall rules are also deleted.

Route 53 Global Resolver is a global service that supports resolvers in multiple Amazon Web Services Regions but you must specify the US East (Ohio) Region to create, update, or otherwise work with Route 53 Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.

Link to this function

disable_dns_view(client, dns_view_id, input, options \\ [])

Disables a DNS view, preventing it from serving DNS queries.

Route 53 Global Resolver is a global service that supports resolvers in multiple Amazon Web Services Regions but you must specify the US East (Ohio) Region to create, update, or otherwise work with Route 53 Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.

Link to this function

disassociate_hosted_zone(client, hosted_zone_id, resource_arn, input, options \\ [])

Disassociates a Route 53 private hosted zone from a Route 53 Global Resolver resource.

Route 53 Global Resolver is a global service that supports resolvers in multiple Amazon Web Services Regions but you must specify the US East (Ohio) Region to create, update, or otherwise work with Route 53 Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.

Link to this function

enable_dns_view(client, dns_view_id, input, options \\ [])

Enables a disabled DNS view, allowing it to serve DNS queries again.

Route 53 Global Resolver is a global service that supports resolvers in multiple Amazon Web Services Regions but you must specify the US East (Ohio) Region to create, update, or otherwise work with Route 53 Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.

Link to this function

get_access_source(client, access_source_id, options \\ [])

Retrieves information about an access source.

Route 53 Global Resolver is a global service that supports resolvers in multiple Amazon Web Services Regions but you must specify the US East (Ohio) Region to create, update, or otherwise work with Route 53 Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.

Link to this function

get_access_token(client, access_token_id, options \\ [])

Retrieves information about an access token.

Route 53 Global Resolver is a global service that supports resolvers in multiple Amazon Web Services Regions but you must specify the US East (Ohio) Region to create, update, or otherwise work with Route 53 Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.

Link to this function

get_dns_view(client, dns_view_id, options \\ [])

Retrieves information about a DNS view.

Route 53 Global Resolver is a global service that supports resolvers in multiple Amazon Web Services Regions but you must specify the US East (Ohio) Region to create, update, or otherwise work with Route 53 Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.

Link to this function

get_firewall_domain_list(client, firewall_domain_list_id, options \\ [])

Retrieves information about a firewall domain list.

Route 53 Global Resolver is a global service that supports resolvers in multiple Amazon Web Services Regions but you must specify the US East (Ohio) Region to create, update, or otherwise work with Route 53 Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.

Link to this function

get_firewall_rule(client, firewall_rule_id, options \\ [])

Retrieves information about a DNS firewall rule.

Route 53 Global Resolver is a global service that supports resolvers in multiple Amazon Web Services Regions but you must specify the US East (Ohio) Region to create, update, or otherwise work with Route 53 Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.

Link to this function

get_global_resolver(client, global_resolver_id, options \\ [])

Retrieves information about a Route 53 Global Resolver instance.

Route 53 Global Resolver is a global service that supports resolvers in multiple Amazon Web Services Regions but you must specify the US East (Ohio) Region to create, update, or otherwise work with Route 53 Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.

Link to this function

get_hosted_zone_association(client, hosted_zone_association_id, options \\ [])

Retrieves information about a hosted zone association.

Route 53 Global Resolver is a global service that supports resolvers in multiple Amazon Web Services Regions but you must specify the US East (Ohio) Region to create, update, or otherwise work with Route 53 Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.

Link to this function

get_managed_firewall_domain_list(client, managed_firewall_domain_list_id, options \\ [])

Retrieves information about an Amazon Web Services-managed firewall domain list.

Managed domain lists contain domains associated with malicious activity, content categories, or specific threats.

Route 53 Global Resolver is a global service that supports resolvers in multiple Amazon Web Services Regions but you must specify the US East (Ohio) Region to create, update, or otherwise work with Route 53 Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.

Link to this function

import_firewall_domains(client, firewall_domain_list_id, input, options \\ [])

Imports a list of domains from an Amazon S3 file into a firewall domain list.

The file should contain one domain per line.

Route 53 Global Resolver is a global service that supports resolvers in multiple Amazon Web Services Regions but you must specify the US East (Ohio) Region to create, update, or otherwise work with Route 53 Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.

Link to this function

list_access_sources(client, filters \\ nil, max_results \\ nil, next_token \\ nil, options \\ [])

Lists all access sources with pagination support.

Route 53 Global Resolver is a global service that supports resolvers in multiple Amazon Web Services Regions but you must specify the US East (Ohio) Region to create, update, or otherwise work with Route 53 Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.

Link to this function

list_access_tokens(client, dns_view_id, filters \\ nil, max_results \\ nil, next_token \\ nil, options \\ [])

Lists all access tokens for a DNS view with pagination support.

Route 53 Global Resolver is a global service that supports resolvers in multiple Amazon Web Services Regions but you must specify the US East (Ohio) Region to create, update, or otherwise work with Route 53 Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.

Link to this function

list_dns_views(client, global_resolver_id, max_results \\ nil, next_token \\ nil, options \\ [])

Lists all DNS views for a Route 53 Global Resolver with pagination support.

Route 53 Global Resolver is a global service that supports resolvers in multiple Amazon Web Services Regions but you must specify the US East (Ohio) Region to create, update, or otherwise work with Route 53 Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.

Link to this function

list_firewall_domain_lists(client, global_resolver_id \\ nil, max_results \\ nil, next_token \\ nil, options \\ [])

Lists all firewall domain lists for a Route 53 Global Resolver with pagination support.

Route 53 Global Resolver is a global service that supports resolvers in multiple Amazon Web Services Regions but you must specify the US East (Ohio) Region to create, update, or otherwise work with Route 53 Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.

Link to this function

list_firewall_domains(client, firewall_domain_list_id, max_results \\ nil, next_token \\ nil, options \\ [])

Lists all the domains in DNS Firewall domain list you have created.

Route 53 Global Resolver is a global service that supports resolvers in multiple Amazon Web Services Regions but you must specify the US East (Ohio) Region to create, update, or otherwise work with Route 53 Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.

Link to this function

list_firewall_rules(client, filters \\ nil, dns_view_id, max_results \\ nil, next_token \\ nil, options \\ [])

Lists all DNS firewall rules for a DNS view with pagination support.

Route 53 Global Resolver is a global service that supports resolvers in multiple Amazon Web Services Regions but you must specify the US East (Ohio) Region to create, update, or otherwise work with Route 53 Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.

Link to this function

list_global_resolvers(client, max_results \\ nil, next_token \\ nil, options \\ [])

Lists all Route 53 Global Resolver instances in your account with pagination support.

Route 53 Global Resolver is a global service that supports resolvers in multiple Amazon Web Services Regions but you must specify the US East (Ohio) Region to create, update, or otherwise work with Route 53 Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.

Link to this function

list_hosted_zone_associations(client, resource_arn, max_results \\ nil, next_token \\ nil, options \\ [])

Lists all hosted zone associations for a Route 53 Global Resolver resource with pagination support.

Route 53 Global Resolver is a global service that supports resolvers in multiple Amazon Web Services Regions but you must specify the US East (Ohio) Region to create, update, or otherwise work with Route 53 Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.

Link to this function

list_managed_firewall_domain_lists(client, managed_firewall_domain_list_type, max_results \\ nil, next_token \\ nil, options \\ [])

Returns a paginated list of the Amazon Web Services Managed DNS Lists and the categories for DNS Firewall.

The categories are either THREAT or CONTENT.

Route 53 Global Resolver is a global service that supports resolvers in multiple Amazon Web Services Regions but you must specify the US East (Ohio) Region to create, update, or otherwise work with Route 53 Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.

Link to this function

list_tags_for_resource(client, input, options \\ [])

Lists the tags associated with a Route 53 Global Resolver resource.

Route 53 Global Resolver is a global service that supports resolvers in multiple Amazon Web Services Regions but you must specify the US East (Ohio) Region to create, update, or otherwise work with Route 53 Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.

Link to this function

tag_resource(client, input, options \\ [])

Adds or updates tags for a Route 53 Global Resolver resource.

Tags are key-value pairs that help you organize and identify your resources.

Route 53 Global Resolver is a global service that supports resolvers in multiple Amazon Web Services Regions but you must specify the US East (Ohio) Region to create, update, or otherwise work with Route 53 Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.

Link to this function

untag_resource(client, input, options \\ [])

Removes tags from a Route 53 Global Resolver resource.

Route 53 Global Resolver is a global service that supports resolvers in multiple Amazon Web Services Regions but you must specify the US East (Ohio) Region to create, update, or otherwise work with Route 53 Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.

Link to this function

update_access_source(client, access_source_id, input, options \\ [])

Updates the configuration of an access source.

Route 53 Global Resolver is a global service that supports resolvers in multiple Amazon Web Services Regions but you must specify the US East (Ohio) Region to create, update, or otherwise work with Route 53 Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.

Link to this function

update_access_token(client, access_token_id, input, options \\ [])

Updates the configuration of an access token.

Route 53 Global Resolver is a global service that supports resolvers in multiple Amazon Web Services Regions but you must specify the US East (Ohio) Region to create, update, or otherwise work with Route 53 Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.

Link to this function

update_dns_view(client, dns_view_id, input, options \\ [])

Updates the configuration of a DNS view.

Route 53 Global Resolver is a global service that supports resolvers in multiple Amazon Web Services Regions but you must specify the US East (Ohio) Region to create, update, or otherwise work with Route 53 Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.

Link to this function

update_firewall_domains(client, firewall_domain_list_id, input, options \\ [])

Updates a DNS Firewall domain list from an array of specified domains.

Route 53 Global Resolver is a global service that supports resolvers in multiple Amazon Web Services Regions but you must specify the US East (Ohio) Region to create, update, or otherwise work with Route 53 Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.

Link to this function

update_firewall_rule(client, firewall_rule_id, input, options \\ [])

Updates the configuration of a DNS firewall rule.

Route 53 Global Resolver is a global service that supports resolvers in multiple Amazon Web Services Regions but you must specify the US East (Ohio) Region to create, update, or otherwise work with Route 53 Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.

Link to this function

update_global_resolver(client, global_resolver_id, input, options \\ [])

Updates the configuration of a Route 53 Global Resolver instance.

You can modify the name, description, and observability Region.

Route 53 Global Resolver is a global service that supports resolvers in multiple Amazon Web Services Regions but you must specify the US East (Ohio) Region to create, update, or otherwise work with Route 53 Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.

Link to this function

update_hosted_zone_association(client, hosted_zone_association_id, input, options \\ [])

Updates the configuration of a hosted zone association.

Route 53 Global Resolver is a global service that supports resolvers in multiple Amazon Web Services Regions but you must specify the US East (Ohio) Region to create, update, or otherwise work with Route 53 Global Resolver resources. That is, for example, specify --region us-east-2 on Amazon Web Services CLI commands.