View Source AWS.S3Tables (aws-elixir v1.0.11)

An Amazon S3 table represents a structured dataset consisting of tabular data in Apache Parquet format and related metadata. This data is stored inside an S3 table as a subresource. All tables in a table bucket are stored in the Apache Iceberg table format. Through integration with the Amazon Web Services Glue Data Catalog you can interact with your tables using Amazon Web Services analytics services, such as Amazon Athena and Amazon Redshift. Amazon S3 manages maintenance of your tables through automatic file compaction and snapshot management. For more information, see Amazon S3 table buckets.

Link to this section Summary

Functions

Creates a new table associated with the given namespace in a table bucket.

Deletes the encryption configuration for a table bucket.

Deletes the replication configuration for a table bucket.

Deletes the replication configuration for a specific table.

Gets the encryption configuration for a table bucket.

Gets details about a maintenance configuration for a given table bucket.

Gets the metrics configuration for a table bucket.

Gets details about a table bucket policy.

Retrieves the replication configuration for a table bucket.This operation returns the IAM role, versionToken, and replication rules that define how tables in this bucket are replicated to other buckets.

Retrieves the storage class configuration for a specific table.

Gets details about the maintenance configuration of a table.

Retrieves the expiration configuration settings for records in a table, and the status of the configuration.

Retrieves the status, metrics, and details of the latest record expiration job for a table.

Retrieves the replication configuration for a specific table.

Retrieves the replication status for a table, including the status of replication to each destination.

Retrieves the storage class configuration for a specific table.

Lists all of the tags applied to a specified Amazon S3 Tables resource.

Sets the encryption configuration for a table bucket.

Creates a new maintenance configuration or replaces an existing maintenance configuration for a table bucket.

Creates a new table bucket policy or replaces an existing table bucket policy for a table bucket.

Creates or updates the replication configuration for a table bucket.

Sets or updates the storage class configuration for a table bucket.

Creates a new maintenance configuration or replaces an existing maintenance configuration for a table.

Creates a new table policy or replaces an existing table policy for a table.

Creates or updates the expiration configuration settings for records in a table, including the status of the configuration.

Creates or updates the replication configuration for a specific table.

Applies one or more user-defined tags to an Amazon S3 Tables resource or updates existing tags.

Removes the specified user-defined tags from an Amazon S3 Tables resource.

Link to this section Functions

Link to this function

create_namespace(client, table_bucket_arn, input, options \\ [])

Creates a namespace.

A namespace is a logical grouping of tables within your table bucket, which you can use to organize tables. For more information, see Create a namespace in the Amazon Simple Storage Service User Guide.

definitions

Definitions

permissions

Permissions

You must have the s3tables:CreateNamespace permission to use this operation.

Link to this function

create_table(client, namespace, table_bucket_arn, input, options \\ [])

Creates a new table associated with the given namespace in a table bucket.

For more information, see Creating an Amazon S3 table in the Amazon Simple Storage Service User Guide.

definitions

Definitions

permissions

Permissions

You must have the s3tables:CreateTable permission to use this operation.

If you use this operation with the optional metadata request parameter you must have the s3tables:PutTableData permission.

If you use this operation with the optional encryptionConfiguration request parameter you must have the s3tables:PutTableEncryption permission.

If you use this operation with the storageClassConfiguration request parameter, you must have the s3tables:PutTableStorageClass permission.

To create a table with tags, you must have the s3tables:TagResource permission in addition to s3tables:CreateTable permission.

Additionally, If you choose SSE-KMS encryption you must grant the S3 Tables maintenance principal access to your KMS key. For more information, see Permissions requirements for S3 Tables SSE-KMS encryption.

Link to this function

create_table_bucket(client, input, options \\ [])

Creates a table bucket.

For more information, see Creating a table bucket in the Amazon Simple Storage Service User Guide.

definitions

Definitions

permissions

Permissions

You must have the s3tables:CreateTableBucket permission to use this operation.

If you use this operation with the optional encryptionConfiguration parameter you must have the s3tables:PutTableBucketEncryption permission.

If you use this operation with the storageClassConfiguration request parameter, you must have the s3tables:PutTableBucketStorageClass permission.

To create a table bucket with tags, you must have the s3tables:TagResource permission in addition to s3tables:CreateTableBucket permission.

Link to this function

delete_namespace(client, namespace, table_bucket_arn, input, options \\ [])

Deletes a namespace.

For more information, see Delete a namespace in the Amazon Simple Storage Service User Guide.

definitions

Definitions

permissions

Permissions

You must have the s3tables:DeleteNamespace permission to use this operation.

Link to this function

delete_table(client, name, namespace, table_bucket_arn, input, options \\ [])

Deletes a table.

For more information, see Deleting an Amazon S3 table in the Amazon Simple Storage Service User Guide.

definitions

Definitions

permissions

Permissions

You must have the s3tables:DeleteTable permission to use this operation.

Link to this function

delete_table_bucket(client, table_bucket_arn, input, options \\ [])

Deletes a table bucket.

For more information, see Deleting a table bucket in the Amazon Simple Storage Service User Guide.

definitions

Definitions

permissions

Permissions

You must have the s3tables:DeleteTableBucket permission to use this operation.

Link to this function

delete_table_bucket_encryption(client, table_bucket_arn, input, options \\ [])

Deletes the encryption configuration for a table bucket.

definitions

Definitions

permissions

Permissions

You must have the s3tables:DeleteTableBucketEncryption permission to use this operation.

Link to this function

delete_table_bucket_metrics_configuration(client, table_bucket_arn, input, options \\ [])

Deletes the metrics configuration for a table bucket.

definitions

Definitions

permissions

Permissions

You must have the s3tables:DeleteTableBucketMetricsConfiguration permission to use this operation.

Link to this function

delete_table_bucket_policy(client, table_bucket_arn, input, options \\ [])

Deletes a table bucket policy.

For more information, see Deleting a table bucket policy in the Amazon Simple Storage Service User Guide.

definitions

Definitions

permissions

Permissions

You must have the s3tables:DeleteTableBucketPolicy permission to use this operation.

Link to this function

delete_table_bucket_replication(client, input, options \\ [])

Deletes the replication configuration for a table bucket.

After deletion, new table updates will no longer be replicated to destination buckets, though existing replicated tables will remain in destination buckets.

definitions

Definitions

permissions

Permissions

You must have the s3tables:DeleteTableBucketReplication permission to use this operation.

Link to this function

delete_table_policy(client, name, namespace, table_bucket_arn, input, options \\ [])

Deletes a table policy.

For more information, see Deleting a table policy in the Amazon Simple Storage Service User Guide.

definitions

Definitions

permissions

Permissions

You must have the s3tables:DeleteTablePolicy permission to use this operation.

Link to this function

delete_table_replication(client, input, options \\ [])

Deletes the replication configuration for a specific table.

After deletion, new updates to this table will no longer be replicated to destination tables, though existing replicated copies will remain in destination buckets.

definitions

Definitions

permissions

Permissions

You must have the s3tables:DeleteTableReplication permission to use this operation.

Link to this function

get_namespace(client, namespace, table_bucket_arn, options \\ [])

Gets details about a namespace.

For more information, see Table namespaces in the Amazon Simple Storage Service User Guide.

definitions

Definitions

permissions

Permissions

You must have the s3tables:GetNamespace permission to use this operation.

Link to this function

get_table(client, name \\ nil, namespace \\ nil, table_arn \\ nil, table_bucket_arn \\ nil, options \\ [])

Gets details about a table.

For more information, see S3 Tables in the Amazon Simple Storage Service User Guide.

definitions

Definitions

permissions

Permissions

You must have the s3tables:GetTable permission to use this operation.

Link to this function

get_table_bucket(client, table_bucket_arn, options \\ [])

Gets details on a table bucket.

For more information, see Viewing details about an Amazon S3 table bucket in the Amazon Simple Storage Service User Guide.

definitions

Definitions

permissions

Permissions

You must have the s3tables:GetTableBucket permission to use this operation.

Link to this function

get_table_bucket_encryption(client, table_bucket_arn, options \\ [])

Gets the encryption configuration for a table bucket.

definitions

Definitions

permissions

Permissions

You must have the s3tables:GetTableBucketEncryption permission to use this operation.

Link to this function

get_table_bucket_maintenance_configuration(client, table_bucket_arn, options \\ [])

Gets details about a maintenance configuration for a given table bucket.

For more information, see Amazon S3 table bucket maintenance in the Amazon Simple Storage Service User Guide.

definitions

Definitions

permissions

Permissions

You must have the s3tables:GetTableBucketMaintenanceConfiguration permission to use this operation.

Link to this function

get_table_bucket_metrics_configuration(client, table_bucket_arn, options \\ [])

Gets the metrics configuration for a table bucket.

definitions

Definitions

permissions

Permissions

You must have the s3tables:GetTableBucketMetricsConfiguration permission to use this operation.

Link to this function

get_table_bucket_policy(client, table_bucket_arn, options \\ [])

Gets details about a table bucket policy.

For more information, see Viewing a table bucket policy in the Amazon Simple Storage Service User Guide.

definitions

Definitions

permissions

Permissions

You must have the s3tables:GetTableBucketPolicy permission to use this operation.

Link to this function

get_table_bucket_replication(client, table_bucket_arn, options \\ [])

Retrieves the replication configuration for a table bucket.This operation returns the IAM role, versionToken, and replication rules that define how tables in this bucket are replicated to other buckets.

definitions

Definitions

permissions

Permissions

You must have the s3tables:GetTableBucketReplication permission to use this operation.

Link to this function

get_table_bucket_storage_class(client, table_bucket_arn, options \\ [])

Retrieves the storage class configuration for a specific table.

This allows you to view the storage class settings that apply to an individual table, which may differ from the table bucket's default configuration.

definitions

Definitions

permissions

Permissions

You must have the s3tables:GetTableBucketStorageClass permission to use this operation.

Link to this function

get_table_encryption(client, name, namespace, table_bucket_arn, options \\ [])

Gets the encryption configuration for a table.

definitions

Definitions

permissions

Permissions

You must have the s3tables:GetTableEncryption permission to use this operation.

Link to this function

get_table_maintenance_configuration(client, name, namespace, table_bucket_arn, options \\ [])

Gets details about the maintenance configuration of a table.

For more information, see S3 Tables maintenance in the Amazon Simple Storage Service User Guide.

definitions

Definitions

permissions

Permissions

You must have the s3tables:GetTableMaintenanceConfiguration permission to use this operation.

You must have the s3tables:GetTableData permission to use set the compaction strategy to sort or zorder.

Link to this function

get_table_maintenance_job_status(client, name, namespace, table_bucket_arn, options \\ [])

Gets the status of a maintenance job for a table.

For more information, see S3 Tables maintenance in the Amazon Simple Storage Service User Guide.

definitions

Definitions

permissions

Permissions

You must have the s3tables:GetTableMaintenanceJobStatus permission to use this operation.

Link to this function

get_table_metadata_location(client, name, namespace, table_bucket_arn, options \\ [])

Gets the location of the table metadata.

definitions

Definitions

permissions

Permissions

You must have the s3tables:GetTableMetadataLocation permission to use this operation.

Link to this function

get_table_policy(client, name, namespace, table_bucket_arn, options \\ [])

Gets details about a table policy.

For more information, see Viewing a table policy in the Amazon Simple Storage Service User Guide.

definitions

Definitions

permissions

Permissions

You must have the s3tables:GetTablePolicy permission to use this operation.

Link to this function

get_table_record_expiration_configuration(client, table_arn, options \\ [])

Retrieves the expiration configuration settings for records in a table, and the status of the configuration.

If the status of the configuration is enabled, records expire and are automatically removed from the table after the specified number of days.

definitions

Definitions

permissions

Permissions

You must have the s3tables:GetTableRecordExpirationConfiguration permission to use this operation.

Link to this function

get_table_record_expiration_job_status(client, table_arn, options \\ [])

Retrieves the status, metrics, and details of the latest record expiration job for a table.

This includes when the job ran, and whether it succeeded or failed. If the job ran successfully, this also includes statistics about the records that were removed.

definitions

Definitions

permissions

Permissions

You must have the s3tables:GetTableRecordExpirationJobStatus permission to use this operation.

Link to this function

get_table_replication(client, table_arn, options \\ [])

Retrieves the replication configuration for a specific table.

definitions

Definitions

permissions

Permissions

You must have the s3tables:GetTableReplication permission to use this operation.

Link to this function

get_table_replication_status(client, table_arn, options \\ [])

Retrieves the replication status for a table, including the status of replication to each destination.

This operation provides visibility into replication health and progress.

definitions

Definitions

permissions

Permissions

You must have the s3tables:GetTableReplicationStatus permission to use this operation.

Link to this function

get_table_storage_class(client, name, namespace, table_bucket_arn, options \\ [])

Retrieves the storage class configuration for a specific table.

This allows you to view the storage class settings that apply to an individual table, which may differ from the table bucket's default configuration.

definitions

Definitions

permissions

Permissions

You must have the s3tables:GetTableStorageClass permission to use this operation.

Link to this function

list_namespaces(client, table_bucket_arn, continuation_token \\ nil, max_namespaces \\ nil, prefix \\ nil, options \\ [])

Lists the namespaces within a table bucket.

For more information, see Table namespaces in the Amazon Simple Storage Service User Guide.

definitions

Definitions

permissions

Permissions

You must have the s3tables:ListNamespaces permission to use this operation.

Link to this function

list_table_buckets(client, continuation_token \\ nil, max_buckets \\ nil, prefix \\ nil, type \\ nil, options \\ [])

Lists table buckets for your account.

For more information, see S3 Table buckets in the Amazon Simple Storage Service User Guide.

definitions

Definitions

permissions

Permissions

You must have the s3tables:ListTableBuckets permission to use this operation.

Link to this function

list_tables(client, table_bucket_arn, continuation_token \\ nil, max_tables \\ nil, namespace \\ nil, prefix \\ nil, options \\ [])

List tables in the given table bucket.

For more information, see S3 Tables in the Amazon Simple Storage Service User Guide.

definitions

Definitions

permissions

Permissions

You must have the s3tables:ListTables permission to use this operation.

Link to this function

list_tags_for_resource(client, resource_arn, options \\ [])

Lists all of the tags applied to a specified Amazon S3 Tables resource.

Each tag is a label consisting of a key and value pair. Tags can help you organize, track costs for, and control access to resources.

For a list of S3 resources that support tagging, see Managing tags for Amazon S3 resources.

definitions

Definitions

permissions

Permissions

For tables and table buckets, you must have the s3tables:ListTagsForResource permission to use this operation.

Link to this function

put_table_bucket_encryption(client, table_bucket_arn, input, options \\ [])

Sets the encryption configuration for a table bucket.

definitions

Definitions

permissions

Permissions

You must have the s3tables:PutTableBucketEncryption permission to use this operation.

If you choose SSE-KMS encryption you must grant the S3 Tables maintenance principal access to your KMS key. For more information, see Permissions requirements for S3 Tables SSE-KMS encryption in the Amazon Simple Storage Service User Guide.

Link to this function

put_table_bucket_maintenance_configuration(client, table_bucket_arn, type, input, options \\ [])

Creates a new maintenance configuration or replaces an existing maintenance configuration for a table bucket.

For more information, see Amazon S3 table bucket maintenance in the Amazon Simple Storage Service User Guide.

definitions

Definitions

permissions

Permissions

You must have the s3tables:PutTableBucketMaintenanceConfiguration permission to use this operation.

Link to this function

put_table_bucket_metrics_configuration(client, table_bucket_arn, input, options \\ [])

Sets the metrics configuration for a table bucket.

definitions

Definitions

permissions

Permissions

You must have the s3tables:PutTableBucketMetricsConfiguration permission to use this operation.

Link to this function

put_table_bucket_policy(client, table_bucket_arn, input, options \\ [])

Creates a new table bucket policy or replaces an existing table bucket policy for a table bucket.

For more information, see Adding a table bucket policy in the Amazon Simple Storage Service User Guide.

definitions

Definitions

permissions

Permissions

You must have the s3tables:PutTableBucketPolicy permission to use this operation.

Link to this function

put_table_bucket_replication(client, input, options \\ [])

Creates or updates the replication configuration for a table bucket.

This operation defines how tables in the source bucket are replicated to destination buckets. Replication helps ensure data availability and disaster recovery across regions or accounts.

definitions

Definitions

permissions

Permissions

You must have the s3tables:PutTableBucketReplication permission to use this operation. The IAM role specified in the configuration must have permissions to read from the source bucket and write permissions to all destination buckets.

You must also have the following permissions:

 `s3tables:GetTable` permission on the source table.

 `s3tables:ListTables` permission on the bucket

containing the table.

 `s3tables:CreateTable` permission for the destination.

 `s3tables:CreateNamespace` permission for the

destination.

 `s3tables:GetTableMaintenanceConfig` permission for the

source bucket.

 `s3tables:PutTableMaintenanceConfig` permission for the

destination bucket.

You must have iam:PassRole permission with condition allowing roles to be passed to replication.s3tables.amazonaws.com.

Link to this function

put_table_bucket_storage_class(client, table_bucket_arn, input, options \\ [])

Sets or updates the storage class configuration for a table bucket.

This configuration serves as the default storage class for all new tables created in the bucket, allowing you to optimize storage costs at the bucket level.

definitions

Definitions

permissions

Permissions

You must have the s3tables:PutTableBucketStorageClass permission to use this operation.

Link to this function

put_table_maintenance_configuration(client, name, namespace, table_bucket_arn, type, input, options \\ [])

Creates a new maintenance configuration or replaces an existing maintenance configuration for a table.

For more information, see S3 Tables maintenance in the Amazon Simple Storage Service User Guide.

definitions

Definitions

permissions

Permissions

You must have the s3tables:PutTableMaintenanceConfiguration permission to use this operation.

Link to this function

put_table_policy(client, name, namespace, table_bucket_arn, input, options \\ [])

Creates a new table policy or replaces an existing table policy for a table.

For more information, see Adding a table policy in the Amazon Simple Storage Service User Guide.

definitions

Definitions

permissions

Permissions

You must have the s3tables:PutTablePolicy permission to use this operation.

Link to this function

put_table_record_expiration_configuration(client, input, options \\ [])

Creates or updates the expiration configuration settings for records in a table, including the status of the configuration.

If you enable record expiration for a table, records expire and are automatically removed from the table after the number of days that you specify.

definitions

Definitions

permissions

Permissions

You must have the s3tables:PutTableRecordExpirationConfiguration permission to use this operation.

Link to this function

put_table_replication(client, input, options \\ [])

Creates or updates the replication configuration for a specific table.

This operation allows you to define table-level replication independently of bucket-level replication, providing granular control over which tables are replicated and where.

definitions

Definitions

permissions

Permissions

You must have the s3tables:PutTableReplication permission to use this operation. The IAM role specified in the configuration must have permissions to read from the source table and write to all destination tables.

You must also have the following permissions:

 `s3tables:GetTable` permission on the source table

being replicated.

 `s3tables:CreateTable` permission for the destination.

 `s3tables:CreateNamespace` permission for the

destination.

 `s3tables:GetTableMaintenanceConfig` permission for the

source table.

 `s3tables:PutTableMaintenanceConfig` permission for the

destination table.

You must have iam:PassRole permission with condition allowing roles to be passed to replication.s3tables.amazonaws.com.

Link to this function

rename_table(client, name, namespace, table_bucket_arn, input, options \\ [])

Renames a table or a namespace.

For more information, see S3 Tables in the Amazon Simple Storage Service User Guide.

definitions

Definitions

permissions

Permissions

You must have the s3tables:RenameTable permission to use this operation.

Link to this function

tag_resource(client, resource_arn, input, options \\ [])

Applies one or more user-defined tags to an Amazon S3 Tables resource or updates existing tags.

Each tag is a label consisting of a key and value pair. Tags can help you organize, track costs for, and control access to your resources. You can add up to 50 tags for each S3 resource.

For a list of S3 resources that support tagging, see Managing tags for Amazon S3 resources.

definitions

Definitions

permissions

Permissions

For tables and table buckets, you must have the s3tables:TagResource permission to use this operation.

Link to this function

untag_resource(client, resource_arn, input, options \\ [])

Removes the specified user-defined tags from an Amazon S3 Tables resource.

You can pass one or more tag keys.

For a list of S3 resources that support tagging, see Managing tags for Amazon S3 resources.

definitions

Definitions

permissions

Permissions

For tables and table buckets, you must have the s3tables:UntagResource permission to use this operation.

Link to this function

update_table_metadata_location(client, name, namespace, table_bucket_arn, input, options \\ [])

Updates the metadata location for a table.

The metadata location of a table must be an S3 URI that begins with the table's warehouse location. The metadata location for an Apache Iceberg table must end with .metadata.json, or if the metadata file is Gzip-compressed, .metadata.json.gz.

definitions

Definitions

permissions

Permissions

You must have the s3tables:UpdateTableMetadataLocation permission to use this operation.