View Source AWS.SecurityHub (aws-elixir v1.0.11)
Security Hub CSPM provides you with a comprehensive view of your security state in Amazon Web Services and helps you assess your Amazon Web Services environment against security industry standards and best practices.
Security Hub CSPM collects security data across Amazon Web Services accounts, Amazon Web Services services, and supported third-party products and helps you analyze your security trends and identify the highest priority security issues.
To help you manage the security state of your organization, Security Hub CSPM supports multiple security standards. These include the Amazon Web Services Foundational Security Best Practices (FSBP) standard developed by Amazon Web Services, and external compliance frameworks such as the Center for Internet Security (CIS), the Payment Card Industry Data Security Standard (PCI DSS), and the National Institute of Standards and Technology (NIST). Each standard includes several security controls, each of which represents a security best practice. Security Hub CSPM runs checks against security controls and generates control findings to help you assess your compliance against security best practices.
In addition to generating control findings, Security Hub CSPM also receives findings from other Amazon Web Services services, such as Amazon GuardDuty and Amazon Inspector, and supported third-party products. This gives you a single pane of glass into a variety of security-related issues. You can also send Security Hub CSPM findings to other Amazon Web Services services and supported third-party products.
Security Hub CSPM offers automation features that help you triage and remediate security issues. For example, you can use automation rules to automatically update critical findings when a security check fails. You can also leverage the integration with Amazon EventBridge to trigger automatic responses to specific findings.
This guide, the Security Hub CSPM API Reference, provides information about the Security Hub CSPM API. This includes supported resources, HTTP methods, parameters, and schemas. If you're new to Security Hub CSPM, you might find it helpful to also review the Security Hub CSPM User Guide . The user guide explains key concepts and provides procedures that demonstrate how to use Security Hub CSPM features. It also provides information about topics such as integrating Security Hub CSPM with other Amazon Web Services services.
In addition to interacting with Security Hub CSPM by making calls to the Security Hub CSPM API, you can use a current version of an Amazon Web Services command line tool or SDK. Amazon Web Services provides tools and SDKs that consist of libraries and sample code for various languages and platforms, such as PowerShell, Java, Go, Python, C++, and .NET. These tools and SDKs provide convenient, programmatic access to Security Hub CSPM and other Amazon Web Services services . They also handle tasks such as signing requests, managing errors, and retrying requests automatically. For information about installing and using the Amazon Web Services tools and SDKs, see Tools to Build on Amazon Web Services.
With the exception of operations that are related to central configuration, Security Hub CSPM API requests are executed only in the Amazon Web Services Region that is currently active or in the specific Amazon Web Services Region that you specify in your request. Any configuration or settings change that results from the operation is applied only to that Region. To make the same change in other Regions, call the same API operation in each Region in which you want to apply the change. When you use central configuration, API requests for enabling Security Hub CSPM, standards, and controls are executed in the home Region and all linked Regions. For a list of central configuration operations, see the Central configuration terms and concepts section of the Security Hub CSPM User Guide.
The following throttling limits apply to Security Hub CSPM API operations.
*
BatchEnableStandards - RateLimit of 1 request per
second. BurstLimit of 1 request per second.
*
GetFindings - RateLimit of 3 requests per second.
BurstLimit of 6 requests per second.
*
BatchImportFindings - RateLimit of 10 requests per second.
BurstLimit of 30 requests per second.
*
BatchUpdateFindings - RateLimit of 10 requests per second.
BurstLimit of 30 requests per second.
*
UpdateStandardsControl - RateLimit of 1 request per
second. BurstLimit of 5 requests per second.
*
All other operations - RateLimit of 10 requests per second.
BurstLimit of 30 requests per second.
Link to this section Summary
Functions
We recommend using Organizations instead of Security Hub CSPM invitations to manage your member accounts.
This method is deprecated.
Deletes one or more automation rules.
Disables the standards specified by the provided
StandardsSubscriptionArns.
Enables the standards specified by the provided StandardsArn.
Retrieves a list of details for automation rules based on rule Amazon Resource Names (ARNs).
Returns associations between an Security Hub CSPM configuration and a batch of target accounts, organizational units, or the root.
Provides details about a batch of security controls for the current Amazon Web Services account and Amazon Web Services Region.
For a batch of security controls and standards, identifies whether each control is currently enabled or disabled in a standard.
Imports security findings generated by a finding provider into Security Hub CSPM.
Updates one or more automation rules based on rule Amazon Resource Names (ARNs) and input parameters.
Used by Security Hub CSPM customers to update information about their investigation into one or more findings.
Updates information about a customer's investigation into a finding.
For a batch of security controls and standards, this operation updates the enablement status of a control in a standard.
Creates a custom action target in Security Hub CSPM.
Enables aggregation across Amazon Web Services Regions.
Creates an automation rule based on input parameters.
Creates a V2 automation rule.
Creates a configuration policy with the defined configuration.
Grants permission to create a connectorV2 based on input parameters.
The aggregation Region is now called the home Region.
Creates a custom insight in Security Hub CSPM.
Creates a member association in Security Hub CSPM between the specified accounts and the account used to make the request, which is the administrator account.
Grants permission to create a ticket in the chosen ITSM based on finding information for the provided finding metadata UID.
We recommend using Organizations instead of Security Hub CSPM invitations to manage your member accounts.
Deletes a custom action target from Security Hub CSPM.
Deletes the Aggregator V2.
Deletes a V2 automation rule.
Deletes a configuration policy.
Grants permission to delete a connectorV2.
The aggregation Region is now called the home Region.
Deletes the insight specified by the InsightArn.
We recommend using Organizations instead of Security Hub CSPM invitations to manage your member accounts.
Deletes the specified member accounts from Security Hub CSPM.
Returns a list of the custom action targets in Security Hub CSPM in your account.
Returns details about the Hub resource in your account, including the
HubArn and the time when you enabled Security Hub CSPM.
Returns information about the way your organization is configured in Security Hub CSPM.
Returns information about product integrations in Security Hub CSPM.
Gets information about the product integration.
Returns details about the service resource in your account.
Returns a list of the available standards in Security Hub CSPM.
Returns a list of security standards controls.
Disables the integration of the specified product with Security Hub CSPM.
Disables a Security Hub CSPM administrator account.
Disables Security Hub CSPM in your account only in the current Amazon Web Services Region.
Disable the service for the current Amazon Web Services Region or specified Amazon Web Services Region.
Disassociates the current Security Hub CSPM member account from the associated administrator account.
This method is deprecated.
Disassociates the specified member accounts from the associated administrator account.
Enables the integration of a partner product with Security Hub CSPM.
Designates the Security Hub CSPM administrator account for an organization.
Enables Security Hub CSPM for your account in the current Region or the Region you specify in the request.
Enables the service in account for the current Amazon Web Services Region or specified Amazon Web Services Region.
Begins the recommended policy generation to remediate a Security Hub finding.
Provides the details for the Security Hub CSPM administrator account for the current member account.
Returns the configuration of the specified Aggregator V2.
Returns an automation rule for the V2 service.
Provides information about a configuration policy.
Returns the association between a configuration and a target account, organizational unit, or the root.
Grants permission to retrieve details for a connectorV2 based on connector id.
Returns a list of the standards that are currently enabled.
The aggregation Region is now called the home Region.
Returns the history of a Security Hub CSPM finding.
Returns aggregated statistical data about findings.
Returns a list of findings that match the specified criteria.
Returns findings trend data based on the specified criteria.
Returns a list of findings that match the specified criteria.
Lists the results of the Security Hub CSPM insight specified by the insight ARN.
Lists and describes insights for the specified insight ARNs.
We recommend using Organizations instead of Security Hub CSPM invitations to manage your member accounts.
This method is deprecated.
Returns the details for the Security Hub CSPM member accounts for the specified account IDs.
Retrieves the recommended policy to remediate a Security Hub finding.
Retrieves statistical information about Amazon Web Services resources and their associated security findings.
Returns resource trend data based on the specified criteria.
Returns a list of resources.
Retrieves the definition of a security control.
We recommend using Organizations instead of Security Hub CSPM invitations to manage your member accounts.
Retrieves a list of V2 aggregators.
A list of automation rules and their metadata for the calling account.
Returns a list of automation rules and metadata for the calling account.
Lists the configuration policies that the Security Hub CSPM delegated administrator has created for your organization.
Provides information about the associations for your configuration policies and self-managed behavior.
Grants permission to retrieve a list of connectorsV2 and their metadata for the calling account.
Lists all findings-generating solutions (products) that you are subscribed to receive findings from in Security Hub CSPM.
If cross-Region aggregation is enabled, then ListFindingAggregators returns
the Amazon Resource Name (ARN)
of the finding aggregator.
We recommend using Organizations instead of Security Hub CSPM invitations to manage your member accounts.
Lists details about all member accounts for the current Security Hub CSPM administrator account.
Lists the Security Hub CSPM administrator accounts.
Lists all of the security controls that apply to a specified standard.
Specifies whether a control is currently enabled or disabled in each enabled standard in the calling account.
Returns a list of tags associated with a resource.
Grants permission to complete the authorization based on input parameters.
Associates a target account, organizational unit, or the root with a specified configuration.
Disassociates a target account, organizational unit, or the root from a specified configuration.
Adds one or more tags to a resource.
Removes one or more tags from a resource.
Updates the name and description of a custom action target in Security Hub CSPM.
Udpates the configuration for the Aggregator V2.
Updates a V2 automation rule.
Updates a configuration policy.
Grants permission to update a connectorV2 based on its id and input parameters.
The aggregation Region is now called the home Region.
UpdateFindings is a deprecated operation.
Updates the Security Hub CSPM insight identified by the specified insight ARN.
Updates the configuration of your organization in Security Hub CSPM.
Updates the properties of a security control.
Updates configuration options for Security Hub CSPM.
Used to control whether an individual security standard control is enabled or disabled.
Link to this section Functions
We recommend using Organizations instead of Security Hub CSPM invitations to manage your member accounts.
For information, see Managing Security Hub CSPM administrator and member accounts with Organizations in the Security Hub CSPM User Guide.
Accepts the invitation to be a member account and be monitored by the Security Hub CSPM administrator account that the invitation was sent from.
This operation is only used by member accounts that are not added through Organizations.
When the member account accepts the invitation, permission is granted to the administrator account to view findings generated in the member account.
This method is deprecated.
Instead, use AcceptAdministratorInvitation.
The Security Hub CSPM console continues to use AcceptInvitation. It will
eventually change to use AcceptAdministratorInvitation. Any IAM policies that
specifically control access to this function must continue to use
AcceptInvitation. You should also add AcceptAdministratorInvitation to your
policies to ensure that the correct permissions are in place after the console
begins to use AcceptAdministratorInvitation.
Accepts the invitation to be a member account and be monitored by the Security Hub CSPM administrator account that the invitation was sent from.
This operation is only used by member accounts that are not added through Organizations.
When the member account accepts the invitation, permission is granted to the administrator account to view findings generated in the member account.
Deletes one or more automation rules.
Disables the standards specified by the provided
StandardsSubscriptionArns.
For more information, see Security Standards section of the Security Hub CSPM User Guide.
Enables the standards specified by the provided StandardsArn.
To obtain the
ARN for a standard, use the DescribeStandards
operation.
For more information, see the Security Standards section of the Security Hub CSPM User Guide.
Retrieves a list of details for automation rules based on rule Amazon Resource Names (ARNs).
batch_get_configuration_policy_associations(client, input, options \\ [])
View SourceReturns associations between an Security Hub CSPM configuration and a batch of target accounts, organizational units, or the root.
Only the Security Hub CSPM delegated administrator can invoke this operation from the home Region. A configuration can refer to a configuration policy or to a self-managed configuration.
Provides details about a batch of security controls for the current Amazon Web Services account and Amazon Web Services Region.
batch_get_standards_control_associations(client, input, options \\ [])
View SourceFor a batch of security controls and standards, identifies whether each control is currently enabled or disabled in a standard.
Calls to this operation return a RESOURCE_NOT_FOUND_EXCEPTION error when the
standard subscription for the association has a NOT_READY_FOR_UPDATES value
for StandardsControlsUpdatable.
Imports security findings generated by a finding provider into Security Hub CSPM.
This action is requested by the finding provider to import its findings into Security Hub CSPM.
BatchImportFindings must be called by one of the following:
*
The Amazon Web Services account that is associated with a finding if you are
using
the default product ARN
or are a partner sending findings from within a customer's Amazon Web Services
account.
In these cases, the identifier of the account that you are calling
BatchImportFindings
from needs to be the same as the AwsAccountId attribute for the finding.
*
An Amazon Web Services account that Security Hub CSPM has allow-listed for an
official partner
integration. In this case, you can call BatchImportFindings from the
allow-listed
account and send findings from different customer accounts in the same batch.
The maximum allowed size for a finding is 240 Kb. An error is returned for any finding larger than 240 Kb.
After a finding is created, BatchImportFindings cannot be used to update
the following finding fields and objects, which Security Hub CSPM customers use
to manage their
investigation workflow.
*
Note
*
UserDefinedFields
*
VerificationState
*
Workflow
Finding providers also should not use BatchImportFindings to update the
following attributes.
*
Confidence
*
Criticality
*
RelatedFindings
*
Severity
*
Types
Instead, finding providers use FindingProviderFields to provide values for
these attributes.
Updates one or more automation rules based on rule Amazon Resource Names (ARNs) and input parameters.
Used by Security Hub CSPM customers to update information about their investigation into one or more findings.
Requested by administrator accounts or member accounts. Administrator accounts can update findings for their account and their member accounts. A member account can update findings only for their own account. Administrator and member accounts can use this operation to update the following fields and objects for one or more findings:
*
Confidence
*
Criticality
*
Note
*
RelatedFindings
*
Severity
*
Types
*
UserDefinedFields
*
VerificationState
*
Workflow
If you use this operation to update a finding, your updates don’t affect the
value for the UpdatedAt field of the finding.
Also note that it can take several minutes for Security Hub CSPM to process your
request and update each finding specified in the request.
You can configure IAM policies to restrict access to fields and field values. For example, you might not want member accounts to be able to suppress findings or change the finding severity. For more information see Configuring access to BatchUpdateFindings in the Security Hub CSPM User Guide.
Updates information about a customer's investigation into a finding.
Delegated administrator accounts can update findings for their account and their member accounts. Member accounts can update findings for their own account.
BatchUpdateFindings and BatchUpdateFindingsV2 both use
securityhub:BatchUpdateFindings in the Action element of an IAM policy
statement.
You must have permission to perform the securityhub:BatchUpdateFindings
action.
You can configure IAM policies to restrict access to specific finding fields or
field values by using the securityhub:OCSFSyntaxPath/ condition key, where ` is one of the following supported fields:SeverityId,StatusId, orComment. To prevent a user from updating a specific field, use aNullcondition withsecurityhub:OCSFSyntaxPath/set to"false". To prevent a user from setting a field to a specific value, use aStringEqualscondition withsecurityhub:OCSFSyntaxPath/set to the disallowed value or list of values. Updates fromBatchUpdateFindingsV2don't affect the value offinding_info.modified_time,finding_info.modified_time_dt,time, ortime_dt` for a finding.
batch_update_standards_control_associations(client, input, options \\ [])
View SourceFor a batch of security controls and standards, this operation updates the enablement status of a control in a standard.
Creates a custom action target in Security Hub CSPM.
You can use custom actions on findings and insights in Security Hub CSPM to trigger target actions in Amazon CloudWatch Events.
Enables aggregation across Amazon Web Services Regions.
Creates an automation rule based on input parameters.
Creates a V2 automation rule.
Creates a configuration policy with the defined configuration.
Only the Security Hub CSPM delegated administrator can invoke this operation from the home Region.
Grants permission to create a connectorV2 based on input parameters.
The aggregation Region is now called the home Region.
Used to enable cross-Region aggregation. This operation can be invoked from the home Region only.
For information about how cross-Region aggregation works, see Understanding cross-Region aggregation in Security Hub CSPM in the Security Hub CSPM User Guide.
Creates a custom insight in Security Hub CSPM.
An insight is a consolidation of findings that relate to a security issue that requires attention or remediation.
To group the related findings in the insight, use the
GroupByAttribute.
Creates a member association in Security Hub CSPM between the specified accounts and the account used to make the request, which is the administrator account.
If you are integrated with Organizations, then the administrator account is designated by the organization management account.
CreateMembers is always used to add accounts that are not organization
members.
For accounts that are managed using Organizations, CreateMembers is only used
in the following cases:
* Security Hub CSPM is not configured to automatically add new organization accounts.
* The account was disassociated or deleted in Security Hub CSPM.
This action can only be used by an account that has Security Hub CSPM enabled.
To enable Security Hub CSPM, you
can use the EnableSecurityHub operation.
For accounts that are not organization members, you create the account
association and
then send an invitation to the member account. To send the invitation, you use
the
InviteMembers operation. If the account owner accepts
the invitation, the account becomes a member account in Security Hub CSPM.
Accounts that are managed using Organizations don't receive an invitation. They automatically become a member account in Security Hub CSPM.
* If the organization account does not have Security Hub CSPM enabled, then Security Hub CSPM and the default standards are automatically enabled. Note that Security Hub CSPM cannot be enabled automatically for the organization management account. The organization management account must enable Security Hub CSPM before the administrator account enables it as a member account.
* For organization accounts that already have Security Hub CSPM enabled, Security Hub CSPM does not make any other changes to those accounts. It does not change their enabled standards or controls.
A permissions policy is added that permits the administrator account to view the findings generated in the member account.
To remove the association between the administrator and member accounts, use the
DisassociateFromMasterAccount or DisassociateMembers operation.
Grants permission to create a ticket in the chosen ITSM based on finding information for the provided finding metadata UID.
We recommend using Organizations instead of Security Hub CSPM invitations to manage your member accounts.
For information, see Managing Security Hub CSPM administrator and member accounts with Organizations in the Security Hub CSPM User Guide.
Declines invitations to become a Security Hub CSPM member account.
A prospective member account uses this operation to decline an invitation to become a member.
Only member accounts that aren't part of an Amazon Web Services organization should use this operation. Organization accounts don't receive invitations.
delete_action_target(client, action_target_arn, input, options \\ [])
View SourceDeletes a custom action target from Security Hub CSPM.
Deleting a custom action target does not affect any findings or insights that were already sent to Amazon CloudWatch Events using the custom action.
delete_aggregator_v2(client, aggregator_v2_arn, input, options \\ [])
View SourceDeletes the Aggregator V2.
delete_automation_rule_v2(client, identifier, input, options \\ [])
View SourceDeletes a V2 automation rule.
delete_configuration_policy(client, identifier, input, options \\ [])
View SourceDeletes a configuration policy.
Only the Security Hub CSPM delegated administrator can invoke this operation
from the home Region. For the deletion to succeed, you must first disassociate a
configuration policy from target accounts,
organizational units, or the root by invoking the
StartConfigurationPolicyDisassociation operation.
Grants permission to delete a connectorV2.
delete_finding_aggregator(client, finding_aggregator_arn, input, options \\ [])
View SourceThe aggregation Region is now called the home Region.
Deletes a finding aggregator. When you delete the finding aggregator, you stop cross-Region aggregation. Finding replication stops occurring from the linked Regions to the home Region.
When you stop cross-Region aggregation, findings that were already replicated and sent to the home Region are still visible from the home Region. However, new findings and finding updates are no longer replicated and sent to the home Region.
Deletes the insight specified by the InsightArn.
We recommend using Organizations instead of Security Hub CSPM invitations to manage your member accounts.
For information, see Managing Security Hub CSPM administrator and member accounts with Organizations in the Security Hub CSPM User Guide.
Deletes invitations to become a Security Hub CSPM member account.
A Security Hub CSPM administrator account can use this operation to delete invitations sent to one or more prospective member accounts.
This operation is only used to delete invitations that are sent to prospective member accounts that aren't part of an Amazon Web Services organization. Organization accounts don't receive invitations.
Deletes the specified member accounts from Security Hub CSPM.
You can invoke this API only to delete accounts that became members through invitation. You can't invoke this API to delete accounts that belong to an Organizations organization.
Returns a list of the custom action targets in Security Hub CSPM in your account.
Returns details about the Hub resource in your account, including the
HubArn and the time when you enabled Security Hub CSPM.
Returns information about the way your organization is configured in Security Hub CSPM.
Only the Security Hub CSPM administrator account can invoke this operation.
describe_products(client, max_results \\ nil, next_token \\ nil, product_arn \\ nil, options \\ [])
View SourceReturns information about product integrations in Security Hub CSPM.
You can optionally provide an integration ARN. If you provide an integration ARN, then the results only include that integration.
If you don't provide an integration ARN, then the results include all of the available product integrations.
describe_products_v2(client, max_results \\ nil, next_token \\ nil, options \\ [])
View SourceGets information about the product integration.
Returns details about the service resource in your account.
describe_standards(client, max_results \\ nil, next_token \\ nil, options \\ [])
View SourceReturns a list of the available standards in Security Hub CSPM.
For each standard, the results include the standard ARN, the name, and a description.
describe_standards_controls(client, standards_subscription_arn, max_results \\ nil, next_token \\ nil, options \\ [])
View SourceReturns a list of security standards controls.
For each control, the results include information about whether it is currently enabled, the severity, and a link to remediation information.
This operation returns an empty list for standard subscriptions where
StandardsControlsUpdatable has value NOT_READY_FOR_UPDATES.
disable_import_findings_for_product(client, product_subscription_arn, input, options \\ [])
View SourceDisables the integration of the specified product with Security Hub CSPM.
After the integration is disabled, findings from that product are no longer sent to Security Hub CSPM.
Disables a Security Hub CSPM administrator account.
Can only be called by the organization management account.
Disables Security Hub CSPM in your account only in the current Amazon Web Services Region.
To disable Security Hub CSPM in all Regions, you must submit one request per Region where you have enabled Security Hub CSPM.
You can't disable Security Hub CSPM in an account that is currently the Security Hub CSPM administrator.
When you disable Security Hub CSPM, your existing findings and insights and any Security Hub CSPM configuration settings are deleted after 90 days and cannot be recovered. Any standards that were enabled are disabled, and your administrator and member account associations are removed.
If you want to save your existing findings, you must export them before you disable Security Hub CSPM.
Disable the service for the current Amazon Web Services Region or specified Amazon Web Services Region.
disassociate_from_administrator_account(client, input, options \\ [])
View SourceDisassociates the current Security Hub CSPM member account from the associated administrator account.
This operation is only used by accounts that are not part of an organization. For organization accounts, only the administrator account can disassociate a member account.
This method is deprecated.
Instead, use DisassociateFromAdministratorAccount.
The Security Hub CSPM console continues to use DisassociateFromMasterAccount.
It will eventually change to use DisassociateFromAdministratorAccount. Any IAM
policies that specifically control access to this function must continue to use
DisassociateFromMasterAccount. You should also add
DisassociateFromAdministratorAccount to your policies to ensure that the
correct permissions are in place after the console begins to use
DisassociateFromAdministratorAccount.
Disassociates the current Security Hub CSPM member account from the associated administrator account.
This operation is only used by accounts that are not part of an organization. For organization accounts, only the administrator account can disassociate a member account.
Disassociates the specified member accounts from the associated administrator account.
Can be used to disassociate both accounts that are managed using Organizations and accounts that were invited manually.
Enables the integration of a partner product with Security Hub CSPM.
Integrated products send findings to Security Hub CSPM.
When you enable a product integration, a permissions policy that grants permission for the product to send findings to Security Hub CSPM is applied.
Designates the Security Hub CSPM administrator account for an organization.
Can only be called by the organization management account.
Enables Security Hub CSPM for your account in the current Region or the Region you specify in the request.
When you enable Security Hub CSPM, you grant to Security Hub CSPM the permissions necessary to gather findings from other services that are integrated with Security Hub CSPM.
When you use the EnableSecurityHub operation to enable Security Hub CSPM, you
also
automatically enable the following standards:
* Center for Internet Security (CIS) Amazon Web Services Foundations Benchmark v1.2.0
* Amazon Web Services Foundational Security Best Practices
Other standards are not automatically enabled.
To opt out of automatically enabled standards, set
EnableDefaultStandards to false.
After you enable Security Hub CSPM, to enable a standard, use the
BatchEnableStandards operation. To disable a standard, use the
BatchDisableStandards operation.
To learn more, see the setup information in the Security Hub CSPM User Guide.
Enables the service in account for the current Amazon Web Services Region or specified Amazon Web Services Region.
generate_recommended_policy_v2(client, metadata_uid, input, options \\ [])
View SourceBegins the recommended policy generation to remediate a Security Hub finding.
GenerateRecommendedPolicyV2 only supports findings for unused permissions.
Provides the details for the Security Hub CSPM administrator account for the current member account.
Can be used by both member accounts that are managed using Organizations and accounts that were invited manually.
Returns the configuration of the specified Aggregator V2.
Returns an automation rule for the V2 service.
Provides information about a configuration policy.
Only the Security Hub CSPM delegated administrator can invoke this operation from the home Region.
get_configuration_policy_association(client, input, options \\ [])
View SourceReturns the association between a configuration and a target account, organizational unit, or the root.
The configuration can be a configuration policy or self-managed behavior. Only the Security Hub CSPM delegated administrator can invoke this operation from the home Region.
Grants permission to retrieve details for a connectorV2 based on connector id.
Returns a list of the standards that are currently enabled.
get_finding_aggregator(client, finding_aggregator_arn, options \\ [])
View SourceThe aggregation Region is now called the home Region.
Returns the current configuration in the calling account for cross-Region aggregation. A finding aggregator is a resource that establishes the home Region and any linked Regions.
Returns the history of a Security Hub CSPM finding.
The history includes changes made to any fields in
the Amazon Web Services Security Finding Format (ASFF) except top-level
timestamp fields, such as the CreatedAt and
UpdatedAt fields.
This operation might return fewer results than the maximum number of results
(MaxResults) specified in a request, even
when more results are available. If this occurs, the response includes a
NextToken value, which you should use to retrieve
the next set of results in the response. The presence of a NextToken value in
a response doesn't necessarily indicate
that the results are incomplete. However, you should continue to specify a
NextToken value until you receive a
response that doesn't include this value.
Returns aggregated statistical data about findings.
You can use the Scopes parameter to define the data boundary for the query.
Currently, Scopes supports AwsOrganizations, which lets you aggregate
findings from your entire organization or from specific organizational units.
Only the delegated administrator account can use Scopes.
GetFindingStatisticsV2 uses securityhub:GetAdhocInsightResults in the
Action element of an IAM policy statement.
You must have permission to perform the securityhub:GetAdhocInsightResults
action.
Returns a list of findings that match the specified criteria.
If cross-Region aggregation is enabled, then when you call GetFindings from
the home Region, the results include all of the matching findings from both the
home Region and linked Regions.
Returns findings trend data based on the specified criteria.
This operation helps you analyze patterns and changes in findings over time.
Returns a list of findings that match the specified criteria.
You can use the Scopes parameter to define the data boundary for the query.
Currently, Scopes supports AwsOrganizations, which lets you retrieve
findings from your entire organization or from specific organizational units.
Only the delegated administrator account can use Scopes.
You can use the Filters parameter to refine results based on finding
attributes. You can use Scopes and Filters independently or together. When
both are provided, Scopes narrows the data set first, and then Filters
refines results within that scoped data set.
GetFindings and GetFindingsV2 both use securityhub:GetFindings in the
Action element of an IAM policy statement.
You must have permission to perform the securityhub:GetFindings action.
Lists the results of the Security Hub CSPM insight specified by the insight ARN.
Lists and describes insights for the specified insight ARNs.
We recommend using Organizations instead of Security Hub CSPM invitations to manage your member accounts.
For information, see Managing Security Hub CSPM administrator and member accounts with Organizations in the Security Hub CSPM User Guide.
Returns the count of all Security Hub CSPM membership invitations that were sent to the calling member account, not including the currently accepted invitation.
This method is deprecated.
Instead, use GetAdministratorAccount.
The Security Hub CSPM console continues to use GetMasterAccount. It will
eventually change to use GetAdministratorAccount. Any IAM policies that
specifically control access to this function must continue to use
GetMasterAccount. You should also add GetAdministratorAccount to your
policies to ensure that the correct permissions are in place after the console
begins to use GetAdministratorAccount.
Provides the details for the Security Hub CSPM administrator account for the current member account.
Can be used by both member accounts that are managed using Organizations and accounts that were invited manually.
Returns the details for the Security Hub CSPM member accounts for the specified account IDs.
An administrator account can be either the delegated Security Hub CSPM administrator account for an organization or an administrator account that enabled Security Hub CSPM manually.
The results include both member accounts that are managed using Organizations and accounts that were invited manually.
get_recommended_policy_v2(client, metadata_uid, max_results \\ nil, next_token \\ nil, options \\ [])
View SourceRetrieves the recommended policy to remediate a Security Hub finding.
GetRecommendedPolicyV2 only supports findings for unused permissions.
Retrieves statistical information about Amazon Web Services resources and their associated security findings.
You can use the Scopes parameter to define the data boundary for the query.
Currently, Scopes supports AwsOrganizations, which lets you aggregate
resources from your entire organization or from specific organizational units.
Only the delegated administrator account can use Scopes.
Returns resource trend data based on the specified criteria.
This operation helps you analyze patterns and changes in resource compliance over time.
Returns a list of resources.
You can use the Scopes parameter to define the data boundary for the query.
Currently, Scopes supports AwsOrganizations, which lets you retrieve
resources from your entire organization or from specific organizational units.
Only the delegated administrator account can use Scopes.
You can use the Filters parameter to refine results based on resource
attributes. You can use Scopes and Filters independently or together. When
both are provided, Scopes narrows the data set first, and then Filters
refines results within that scoped data set.
get_security_control_definition(client, security_control_id, options \\ [])
View SourceRetrieves the definition of a security control.
The definition includes the control title, description, Region availability, parameter definitions, and other details.
We recommend using Organizations instead of Security Hub CSPM invitations to manage your member accounts.
For information, see Managing Security Hub CSPM administrator and member accounts with Organizations in the Security Hub CSPM User Guide.
Invites other Amazon Web Services accounts to become member accounts for the Security Hub CSPM administrator account that the invitation is sent from.
This operation is only used to invite accounts that don't belong to an Amazon Web Services organization. Organization accounts don't receive invitations.
Before you can use this action to invite a member, you must first use the
CreateMembers action to create the member account in Security Hub CSPM.
When the account owner enables Security Hub CSPM and accepts the invitation to become a member account, the administrator account can view the findings generated in the member account.
list_aggregators_v2(client, max_results \\ nil, next_token \\ nil, options \\ [])
View SourceRetrieves a list of V2 aggregators.
list_automation_rules(client, max_results \\ nil, next_token \\ nil, options \\ [])
View SourceA list of automation rules and their metadata for the calling account.
list_automation_rules_v2(client, max_results \\ nil, next_token \\ nil, options \\ [])
View SourceReturns a list of automation rules and metadata for the calling account.
list_configuration_policies(client, max_results \\ nil, next_token \\ nil, options \\ [])
View SourceLists the configuration policies that the Security Hub CSPM delegated administrator has created for your organization.
Only the delegated administrator can invoke this operation from the home Region.
list_configuration_policy_associations(client, input, options \\ [])
View SourceProvides information about the associations for your configuration policies and self-managed behavior.
Only the Security Hub CSPM delegated administrator can invoke this operation from the home Region.
list_connectors_v2(client, connector_status \\ nil, max_results \\ nil, next_token \\ nil, provider_name \\ nil, options \\ [])
View SourceGrants permission to retrieve a list of connectorsV2 and their metadata for the calling account.
list_enabled_products_for_import(client, max_results \\ nil, next_token \\ nil, options \\ [])
View SourceLists all findings-generating solutions (products) that you are subscribed to receive findings from in Security Hub CSPM.
list_finding_aggregators(client, max_results \\ nil, next_token \\ nil, options \\ [])
View SourceIf cross-Region aggregation is enabled, then ListFindingAggregators returns
the Amazon Resource Name (ARN)
of the finding aggregator.
You can run this operation from any Amazon Web Services Region.
list_invitations(client, max_results \\ nil, next_token \\ nil, options \\ [])
View SourceWe recommend using Organizations instead of Security Hub CSPM invitations to manage your member accounts.
For information, see Managing Security Hub CSPM administrator and member accounts with Organizations in the Security Hub CSPM User Guide.
Lists all Security Hub CSPM membership invitations that were sent to the calling account.
Only accounts that are managed by invitation can use this operation. Accounts that are managed using the integration with Organizations don't receive invitations.
list_members(client, max_results \\ nil, next_token \\ nil, only_associated \\ nil, options \\ [])
View SourceLists details about all member accounts for the current Security Hub CSPM administrator account.
The results include both member accounts that belong to an organization and member accounts that were invited manually.
list_organization_admin_accounts(client, feature \\ nil, max_results \\ nil, next_token \\ nil, options \\ [])
View SourceLists the Security Hub CSPM administrator accounts.
Can only be called by the organization management account.
list_security_control_definitions(client, max_results \\ nil, next_token \\ nil, standards_arn \\ nil, options \\ [])
View SourceLists all of the security controls that apply to a specified standard.
list_standards_control_associations(client, max_results \\ nil, next_token \\ nil, security_control_id, options \\ [])
View SourceSpecifies whether a control is currently enabled or disabled in each enabled standard in the calling account.
This operation omits standards control associations for standard subscriptions
where StandardsControlsUpdatable has value NOT_READY_FOR_UPDATES.
Returns a list of tags associated with a resource.
Grants permission to complete the authorization based on input parameters.
start_configuration_policy_association(client, input, options \\ [])
View SourceAssociates a target account, organizational unit, or the root with a specified configuration.
The target can be associated with a configuration policy or self-managed behavior. Only the Security Hub CSPM delegated administrator can invoke this operation from the home Region.
start_configuration_policy_disassociation(client, input, options \\ [])
View SourceDisassociates a target account, organizational unit, or the root from a specified configuration.
When you disassociate a configuration from its target, the target inherits the configuration of the closest parent. If there’s no configuration to inherit, the target retains its settings but becomes a self-managed account. A target can be disassociated from a configuration policy or self-managed behavior. Only the Security Hub CSPM delegated administrator can invoke this operation from the home Region.
Adds one or more tags to a resource.
Removes one or more tags from a resource.
update_action_target(client, action_target_arn, input, options \\ [])
View SourceUpdates the name and description of a custom action target in Security Hub CSPM.
update_aggregator_v2(client, aggregator_v2_arn, input, options \\ [])
View SourceUdpates the configuration for the Aggregator V2.
update_automation_rule_v2(client, identifier, input, options \\ [])
View SourceUpdates a V2 automation rule.
update_configuration_policy(client, identifier, input, options \\ [])
View SourceUpdates a configuration policy.
Only the Security Hub CSPM delegated administrator can invoke this operation from the home Region.
Grants permission to update a connectorV2 based on its id and input parameters.
The aggregation Region is now called the home Region.
Updates cross-Region aggregation settings. You can use this operation to update the Region linking mode and the list of included or excluded Amazon Web Services Regions. However, you can't use this operation to change the home Region.
You can invoke this operation from the current home Region only.
UpdateFindings is a deprecated operation.
Instead of UpdateFindings, use
the BatchUpdateFindings operation.
The UpdateFindings operation updates the Note and RecordState of the
Security Hub CSPM aggregated
findings that the filter attributes specify. Any member account that can view
the finding
can also see the update to the finding.
Finding updates made with UpdateFindings aren't persisted if the same finding
is later updated by the
finding provider through the BatchImportFindings operation. In addition,
Security Hub CSPM doesn't
record updates made with UpdateFindings in the finding history.
Updates the Security Hub CSPM insight identified by the specified insight ARN.
Updates the configuration of your organization in Security Hub CSPM.
Only the Security Hub CSPM administrator account can invoke this operation.
Updates the properties of a security control.
Updates configuration options for Security Hub CSPM.
update_standards_control(client, standards_control_arn, input, options \\ [])
View SourceUsed to control whether an individual security standard control is enabled or disabled.
Calls to this operation return a RESOURCE_NOT_FOUND_EXCEPTION error when the
standard subscription for the control has StandardsControlsUpdatable value
NOT_READY_FOR_UPDATES.