View Source AWS.SimpleDBv2 (aws-elixir v1.0.11)
Amazon SimpleDB is a web service providing the core database functions of data indexing and querying in the cloud.
By offloading the time and effort associated with building and operating a web-scale database, SimpleDB provides developers the freedom to focus on application development.
A traditional, clustered relational database requires a sizable upfront capital outlay, is complex to design, and often requires extensive and repetitive database administration. Amazon SimpleDB is dramatically simpler, requiring no schema, automatically indexing your data and providing a simple API for storage and access. This approach eliminates the administrative burden of data modeling, index maintenance, and performance tuning. Developers gain access to this functionality within Amazon's proven computing environment, are able to scale instantly, and pay only for what they use.
Link to this section Summary
Functions
Returns information for an existing domain export.
Lists all exports that were created.
Initiates the export of a SimpleDB domain to an S3 bucket.
Link to this section Functions
Returns information for an existing domain export.
Lists all exports that were created.
The results are paginated and can be filtered by domain name.
Initiates the export of a SimpleDB domain to an S3 bucket.