View Source AWS.TrustedAdvisor (aws-elixir v1.0.11)

TrustedAdvisor Public API

Link to this section Summary

Functions

Update one or more exclusion statuses for a list of recommendation resources.

Get a specific recommendation within an AWS Organizations organization.

Link to this section Functions

Link to this function

batch_update_recommendation_resource_exclusion(client, input, options \\ [])

Update one or more exclusion statuses for a list of recommendation resources.

This API supports up to 25 unique recommendation resource ARNs per request. This API currently doesn't support prioritized recommendation resources. This API updates global recommendations, eliminating the need to call the API in each AWS Region. After submitting an exclusion update, note that it might take a few minutes for the changes to be reflected in the system.

Link to this function

get_organization_recommendation(client, organization_recommendation_identifier, options \\ [])

Get a specific recommendation within an AWS Organizations organization.

This API supports only prioritized recommendations and provides global priority recommendations, eliminating the need to call the API in each AWS Region.

Link to this function

get_recommendation(client, recommendation_identifier, language \\ nil, options \\ [])

Get a specific Recommendation.

This API provides global recommendations, eliminating the need to call the API in each AWS Region.

Link to this function

list_checks(client, aws_service \\ nil, language \\ nil, max_results \\ nil, next_token \\ nil, pillar \\ nil, source \\ nil, options \\ [])

List a filterable set of Checks.

This API provides global recommendations, eliminating the need to call the API in each AWS Region.

Link to this function

list_organization_recommendation_accounts(client, organization_recommendation_identifier, affected_account_id \\ nil, max_results \\ nil, next_token \\ nil, options \\ [])

Lists the accounts that own the resources for an organization aggregate recommendation.

This API only supports prioritized recommendations and provides global priority recommendations, eliminating the need to call the API in each AWS Region.

Link to this function

list_organization_recommendation_resources(client, organization_recommendation_identifier, affected_account_id \\ nil, exclusion_status \\ nil, max_results \\ nil, next_token \\ nil, region_code \\ nil, status \\ nil, options \\ [])

List Resources of a Recommendation within an Organization.

This API only supports prioritized recommendations and provides global priority recommendations, eliminating the need to call the API in each AWS Region.

Link to this function

list_organization_recommendations(client, after_last_updated_at \\ nil, aws_service \\ nil, before_last_updated_at \\ nil, check_identifier \\ nil, max_results \\ nil, next_token \\ nil, pillar \\ nil, source \\ nil, status \\ nil, type \\ nil, options \\ [])

List a filterable set of Recommendations within an Organization.

This API only supports prioritized recommendations and provides global priority recommendations, eliminating the need to call the API in each AWS Region.

Link to this function

list_recommendation_resources(client, recommendation_identifier, exclusion_status \\ nil, language \\ nil, max_results \\ nil, next_token \\ nil, region_code \\ nil, status \\ nil, options \\ [])

List Resources of a Recommendation.

This API provides global recommendations, eliminating the need to call the API in each AWS Region.

Link to this function

list_recommendations(client, after_last_updated_at \\ nil, aws_service \\ nil, before_last_updated_at \\ nil, check_identifier \\ nil, language \\ nil, max_results \\ nil, next_token \\ nil, pillar \\ nil, source \\ nil, status \\ nil, type \\ nil, options \\ [])

List a filterable set of Recommendations.

This API provides global recommendations, eliminating the need to call the API in each AWS Region.

Link to this function

update_organization_recommendation_lifecycle(client, organization_recommendation_identifier, input, options \\ [])

Update the lifecycle of a Recommendation within an Organization.

This API only supports prioritized recommendations and updates global priority recommendations, eliminating the need to call the API in each AWS Region.

Link to this function

update_recommendation_lifecycle(client, recommendation_identifier, input, options \\ [])

Update the lifecyle of a Recommendation.

This API only supports prioritized recommendations and updates global priority recommendations, eliminating the need to call the API in each AWS Region.