View Source AWS.ConnectHealth (aws-elixir v1.0.11)
Health Agent for healthcare providers and patient engagement
Link to this section Summary
Functions
Activates a Subscription to enable billing for a user.
Creates a new Domain for managing HealthAgent resources.
Creates a new Subscription within a Domain for billing and user management.
Deactivates a Subscription to stop billing for a user.
Deletes a Domain and all associated resources.
Retrieves information about a Domain.
Retrieves details about an existing Medical Scribe listening session
Get details of a started patient insights job.
Retrieves information about a Subscription.
Lists Domains for a given account.
Lists all Subscriptions within a Domain.
Lists the tags associated with the specified resource
Starts a new Medical Scribe listening session for real-time audio transcription
Starts a new patient insights job.
Associates the specified tags with the specified resource
Removes the specified tags from the specified resource
Link to this section Functions
activate_subscription(client, domain_id, subscription_id, input, options \\ [])
View SourceActivates a Subscription to enable billing for a user.
Creates a new Domain for managing HealthAgent resources.
Creates a new Subscription within a Domain for billing and user management.
deactivate_subscription(client, domain_id, subscription_id, input, options \\ [])
View SourceDeactivates a Subscription to stop billing for a user.
Deletes a Domain and all associated resources.
Retrieves information about a Domain.
get_medical_scribe_listening_session(client, domain_id, session_id, subscription_id, options \\ [])
View SourceRetrieves details about an existing Medical Scribe listening session
get_patient_insights_job(client, domain_id, job_id, options \\ [])
View SourceGet details of a started patient insights job.
get_subscription(client, domain_id, subscription_id, options \\ [])
View SourceRetrieves information about a Subscription.
list_domains(client, max_results \\ nil, next_token \\ nil, status \\ nil, options \\ [])
View SourceLists Domains for a given account.
list_subscriptions(client, domain_id, max_results \\ nil, next_token \\ nil, options \\ [])
View SourceLists all Subscriptions within a Domain.
Lists the tags associated with the specified resource
start_medical_scribe_listening_session(client, input, options \\ [])
View SourceStarts a new Medical Scribe listening session for real-time audio transcription
start_patient_insights_job(client, domain_id, input, options \\ [])
View SourceStarts a new patient insights job.
Associates the specified tags with the specified resource
Removes the specified tags from the specified resource