View Source AWS.Evs (aws-elixir v1.0.11)
Amazon Elastic VMware Service (Amazon EVS) is a service that you can use to deploy a VMware Cloud Foundation (VCF) software environment directly on EC2 bare metal instances within an Amazon Virtual Private Cloud (VPC).
Workloads running on Amazon EVS are fully compatible with workloads running on any standard VMware vSphere environment. This means that you can migrate any VMware-based workload to Amazon EVS without workload modification.
Link to this section Summary
Functions
Associates an Elastic IP address with a public HCX VLAN.
Creates a Windows Server License entitlement for virtual machines in an Amazon EVS environment using the provided vCenter Server connector.
Creates an Amazon EVS environment that runs VCF software, such as SDDC Manager, NSX Manager, and vCenter Server.
Creates a connector for an Amazon EVS environment.
Creates an ESX host and adds it to an Amazon EVS environment.
Deletes a Windows Server License entitlement for virtual machines in an Amazon EVS environment.
Deletes an Amazon EVS environment.
Deletes a connector from an Amazon EVS environment.
Deletes a host from an Amazon EVS environment.
Disassociates an Elastic IP address from a public HCX VLAN.
Returns a description of the specified environment.
Returns information about VCF versions, ESX versions and EC2 instance types provided by Amazon EVS.
Lists the connectors within an environment.
List the hosts within an environment.
Lists environment VLANs that are associated with the specified environment.
Lists the Amazon EVS environments in your Amazon Web Services account in the specified Amazon Web Services Region.
Lists the tags for an Amazon EVS resource.
Lists the Windows Server License entitlements for virtual machines in an Amazon EVS environment.
Associates the specified tags to an Amazon EVS resource with the specified
resourceArn.
Deletes specified tags from an Amazon EVS resource.
Updates a connector for an Amazon EVS environment.
Link to this section Functions
Associates an Elastic IP address with a public HCX VLAN.
This operation is only allowed for public HCX VLANs at this time.
Creates a Windows Server License entitlement for virtual machines in an Amazon EVS environment using the provided vCenter Server connector.
This is an asynchronous operation. Amazon EVS validates the specified virtual machines before starting usage tracking.
Creates an Amazon EVS environment that runs VCF software, such as SDDC Manager, NSX Manager, and vCenter Server.
During environment creation, Amazon EVS performs validations on DNS settings, provisions VLAN subnets and hosts, and deploys the supplied version of VCF.
It can take several hours to create an environment. After the deployment completes, you can configure VCF in the vSphere user interface according to your needs.
When creating a new environment, the default ESX version for the selected VCF
version will be used, you cannot choose a specific ESX version in
CreateEnvironment action. When a host has been added with a specific ESX
version, it can only be upgraded using vCenter Lifecycle Manager.
You cannot use the dedicatedHostId and placementGroupId parameters together
in the same CreateEnvironment action. This results in a ValidationException
response.
Creates a connector for an Amazon EVS environment.
A connector establishes a connection to a VCF appliance, such as vCenter, using a fully qualified domain name and an Amazon Web Services Secrets Manager secret that stores the appliance credentials.
Creates an ESX host and adds it to an Amazon EVS environment.
Amazon EVS supports 4-16 hosts per environment.
This action can only be used after the Amazon EVS environment is deployed.
You can use the dedicatedHostId parameter to specify an Amazon EC2 Dedicated
Host for ESX host creation.
You can use the placementGroupId parameter to specify a cluster or partition
placement group to launch EC2 instances into.
If you don't specify an ESX version when adding hosts using
CreateEnvironmentHost action, Amazon EVS automatically uses the default ESX
version associated with your environment's VCF version. To find the default ESX
version for a particular VCF version, use the GetVersions action.
You cannot use the dedicatedHostId and placementGroupId parameters together
in the same CreateEnvironmentHost action. This results in a
ValidationException response.
Deletes a Windows Server License entitlement for virtual machines in an Amazon EVS environment.
Deleting an entitlement stops usage tracking for the specified virtual machines.
Deletes an Amazon EVS environment.
Amazon EVS environments will only be enabled for deletion once the hosts are
deleted. You can delete hosts using the DeleteEnvironmentHost action.
Environment deletion also deletes the associated Amazon EVS VLAN subnets and Amazon Web Services Secrets Manager secrets that Amazon EVS created. Amazon Web Services resources that you create are not deleted. These resources may continue to incur costs.
Deletes a connector from an Amazon EVS environment.
Before deleting a connector, you must remove all entitlements that are associated with the same vCenter.
Deletes a host from an Amazon EVS environment.
Before deleting a host, you must unassign and decommission the host from within the SDDC Manager user interface. Not doing so could impact the availability of your virtual machines or result in data loss.
Disassociates an Elastic IP address from a public HCX VLAN.
This operation is only allowed for public HCX VLANs at this time.
Returns a description of the specified environment.
Returns information about VCF versions, ESX versions and EC2 instance types provided by Amazon EVS.
For each VCF version, the response also includes the default ESX version and provided EC2 instance types.
Lists the connectors within an environment.
Returns the status of each connector and its applicable checks, among other connector details.
List the hosts within an environment.
Lists environment VLANs that are associated with the specified environment.
Lists the Amazon EVS environments in your Amazon Web Services account in the specified Amazon Web Services Region.
Lists the tags for an Amazon EVS resource.
Lists the Windows Server License entitlements for virtual machines in an Amazon EVS environment.
Returns existing entitlements for virtual machines associated with the specified environment and connector.
Associates the specified tags to an Amazon EVS resource with the specified
resourceArn.
If existing tags on a resource are not specified in the request parameters, they aren't changed. When a resource is deleted, the tags associated with that resource are also deleted. Tags that you create for Amazon EVS resources don't propagate to any other resources associated with the environment. For example, if you tag an environment with this operation, that tag doesn't automatically propagate to the VLAN subnets and hosts associated with the environment.
Deletes specified tags from an Amazon EVS resource.
Updates a connector for an Amazon EVS environment.
You can update the Amazon Web Services Secrets Manager secret ARN or the appliance FQDN to reconfigure the connector metadata.
You cannot update both the secret and the FQDN in the same request.