View Source AWS.Interconnect (aws-elixir v1.0.11)
Provides managed connections between your AWS network resources and select partner network resources.
Link to this section Summary
Functions
Accepts a connection proposal which was generated at a supported partner's portal.
Initiates the process to create a Connection across the specified Environment.
Deletes an existing Connection with the supplied identifier.
Describes the details of a connection proposal generated at a partner's portal.
Describes the current state of a Connection resource as specified by the identifier.
Describes a specific Environment
Lists all Attach Points the caller has access to that are valid for the
specified Environment.
Lists all connection objects to which the caller has access.
Lists all of the environments that can produce connections that will land in the called AWS region.
List all current tags on the specified resource.
Add new tags to the specified resource.
Removes tags from the specified resource.
Modifies an existing connection.
Link to this section Functions
Accepts a connection proposal which was generated at a supported partner's portal.
The proposal contains the Environment and bandwidth that were chosen on the partner's portal and cannot be modified.
Upon accepting the proposal a connection will be made between the AWS network as accessed via the selected Attach Point and the network previously selected network on the partner's portal.
Initiates the process to create a Connection across the specified Environment.
The Environment dictates the specified partner and location to which the other
end of the connection should attach. You can see a list of the available
Environments by calling ListEnvironments
The Attach Point specifies where within the AWS Network your connection will logically connect.
After a successful call to this method, the resulting Connection will return
an Activation Key which will need to be brought to the specific partner's portal
to confirm the Connection on both sides. (See Environment$activationPageUrl
for a direct link to the partner portal).
Deletes an existing Connection with the supplied identifier.
This operation will also inform the remote partner of your intention to delete
your connection. Note, the partner may still require you to delete to fully
clean up resources, but the network connectivity provided by the Connection
will cease to exist.
Describes the details of a connection proposal generated at a partner's portal.
Describes the current state of a Connection resource as specified by the identifier.
Describes a specific Environment
Lists all Attach Points the caller has access to that are valid for the
specified Environment.
Lists all connection objects to which the caller has access.
Allows for optional filtering by the following properties:
stateenvironmentIdproviderattach point
Only Connection objects matching all filters will be returned.
Lists all of the environments that can produce connections that will land in the called AWS region.
List all current tags on the specified resource.
Currently this supports Connection resources.
Add new tags to the specified resource.
Removes tags from the specified resource.
Modifies an existing connection.
Currently we support modifications to the connection's description and/or bandwidth.