View Source AWS.PartnerCentralChannel (aws-elixir v1.0.11)
AWS Partner Central Channel service for managing partner relationships, handshakes, and program management accounts.
Link to this section Summary
Functions
Accepts a pending channel handshake request from another AWS account.
Cancels a pending channel handshake request.
Creates a new channel handshake request to establish a partnership with another AWS account.
Creates a new program management account for managing partner relationships.
Creates a new partner relationship between accounts.
Deletes a program management account.
Deletes a partner relationship.
Retrieves details of a specific partner relationship.
Lists channel handshakes based on specified criteria.
Lists program management accounts based on specified criteria.
Lists partner relationships based on specified criteria.
Lists tags associated with a specific resource.
Rejects a pending channel handshake request.
Adds or updates tags for a specified resource.
Removes tags from a specified resource.
Updates the properties of a program management account.
Updates the properties of a partner relationship.
Link to this section Functions
Accepts a pending channel handshake request from another AWS account.
Cancels a pending channel handshake request.
Creates a new channel handshake request to establish a partnership with another AWS account.
Creates a new program management account for managing partner relationships.
Creates a new partner relationship between accounts.
Deletes a program management account.
Deletes a partner relationship.
Retrieves details of a specific partner relationship.
Lists channel handshakes based on specified criteria.
Lists program management accounts based on specified criteria.
Lists partner relationships based on specified criteria.
Lists tags associated with a specific resource.
Rejects a pending channel handshake request.
Adds or updates tags for a specified resource.
Removes tags from a specified resource.
Updates the properties of a program management account.
Updates the properties of a partner relationship.