View Source AWS.S3Tables (aws-elixir v1.0.5)
An Amazon S3 table represents a structured dataset consisting of tabular data in Apache Parquet format and related metadata. This data is stored inside an S3 table as a subresource. All tables in a table bucket are stored in the Apache Iceberg table format. Through integration with the AWS Glue Data Catalog you can interact with your tables using AWS analytics services, such as Amazon Athena and Amazon Redshift. Amazon S3 manages maintenance of your tables through automatic file compaction and snapshot management. For more information, see Amazon S3 table buckets.
Link to this section Summary
Functions
Creates a namespace.
Creates a new table associated with the given namespace in a table bucket.
Creates a table bucket.
Deletes a namespace.
Deletes a table bucket.
Deletes a table bucket policy.
Deletes a table policy.
Gets details about a namespace.
Gets details about a table.
Gets details on a table bucket.
Gets details about a maintenance configuration for a given table bucket.
Gets details about a table bucket policy.
Gets details about the maintenance configuration of a table.
Gets the status of a maintenance job for a table.
Gets the location of the table metadata.
Gets details about a table policy.
Lists the namespaces within a table bucket.
Lists table buckets for your account.
List tables in the given table bucket.
Creates a new maintenance configuration or replaces an existing maintenance configuration for a table bucket.
Creates a new maintenance configuration or replaces an existing table bucket policy for a table bucket.
Creates a new maintenance configuration or replaces an existing maintenance configuration for a table.
Creates a new maintenance configuration or replaces an existing table policy for a table.
Renames a table or a namespace.
Updates the metadata location for a table.
Link to this section Functions
Creates a namespace.
A namespace is a logical grouping of tables within your table bucket, which you can use to organize tables. For more information, see Create a namespace in the Amazon Simple Storage Service User Guide.
definitions
Definitions
permissions
Permissions
You must have the s3tables:CreateNamespace permission to use this operation.
create_table(client, namespace, table_bucket_arn, input, options \\ [])
View SourceCreates a new table associated with the given namespace in a table bucket.
For more information, see Creating an Amazon S3 table in the Amazon Simple Storage Service User Guide.
definitions
Definitions
permissions
Permissions
You must have the s3tables:CreateTable permission to use this operation.
Additionally, you must have the s3tables:PutTableData permission to use this
operation with the optional metadata request parameter.
Creates a table bucket.
For more information, see Creating a table bucket in the Amazon Simple Storage Service User Guide.
definitions
Definitions
permissions
Permissions
You must have the s3tables:CreateTableBucket permission to use this operation.
delete_namespace(client, namespace, table_bucket_arn, input, options \\ [])
View SourceDeletes a namespace.
For more information, see Delete a namespace in the Amazon Simple Storage Service User Guide.
definitions
Definitions
permissions
Permissions
You must have the s3tables:DeleteNamespace permission to use this operation.
delete_table(client, name, namespace, table_bucket_arn, input, options \\ [])
View SourceDeletes a table.
For more information, see Deleting an Amazon S3 table in the Amazon Simple Storage Service User Guide.
definitions
Definitions
permissions
Permissions
You must have the s3tables:DeleteTable permission to use this operation.
delete_table_bucket(client, table_bucket_arn, input, options \\ [])
View SourceDeletes a table bucket.
For more information, see Deleting a table bucket in the Amazon Simple Storage Service User Guide.
definitions
Definitions
permissions
Permissions
You must have the s3tables:DeleteTableBucket permission to use this operation.
delete_table_bucket_policy(client, table_bucket_arn, input, options \\ [])
View SourceDeletes a table bucket policy.
For more information, see Deleting a table bucket policy in the Amazon Simple Storage Service User Guide.
definitions
Definitions
permissions
Permissions
You must have the s3tables:DeleteTableBucketPolicy permission to use this
operation.
delete_table_policy(client, name, namespace, table_bucket_arn, input, options \\ [])
View SourceDeletes a table policy.
For more information, see Deleting a table policy in the Amazon Simple Storage Service User Guide.
definitions
Definitions
permissions
Permissions
You must have the s3tables:DeleteTablePolicy permission to use this operation.
Gets details about a namespace.
For more information, see Table namespaces in the Amazon Simple Storage Service User Guide.
definitions
Definitions
permissions
Permissions
You must have the s3tables:GetNamespace permission to use this operation.
get_table(client, name, namespace, table_bucket_arn, options \\ [])
View SourceGets details about a table.
For more information, see S3 Tables in the Amazon Simple Storage Service User Guide.
definitions
Definitions
permissions
Permissions
You must have the s3tables:GetTable permission to use this operation.
Gets details on a table bucket.
For more information, see Viewing details about an Amazon S3 table bucket in the Amazon Simple Storage Service User Guide.
definitions
Definitions
permissions
Permissions
You must have the s3tables:GetTableBucket permission to use this operation.
get_table_bucket_maintenance_configuration(client, table_bucket_arn, options \\ [])
View SourceGets details about a maintenance configuration for a given table bucket.
For more information, see Amazon S3 table bucket maintenance in the Amazon Simple Storage Service User Guide.
definitions
Definitions
permissions
Permissions
You must have the s3tables:GetTableBucketMaintenanceConfiguration permission
to use this operation.
Gets details about a table bucket policy.
For more information, see Viewing a table bucket policy in the Amazon Simple Storage Service User Guide.
definitions
Definitions
permissions
Permissions
You must have the s3tables:GetTableBucketPolicy permission to use this
operation.
get_table_maintenance_configuration(client, name, namespace, table_bucket_arn, options \\ [])
View SourceGets details about the maintenance configuration of a table.
For more information, see S3 Tables maintenance in the Amazon Simple Storage Service User Guide.
definitions
Definitions
permissions
Permissions
You must have the s3tables:GetTableMaintenanceConfiguration permission to use
this operation.
get_table_maintenance_job_status(client, name, namespace, table_bucket_arn, options \\ [])
View SourceGets the status of a maintenance job for a table.
For more information, see S3 Tables maintenance in the Amazon Simple Storage Service User Guide.
definitions
Definitions
permissions
Permissions
You must have the s3tables:GetTableMaintenanceJobStatus permission to use this
operation.
get_table_metadata_location(client, name, namespace, table_bucket_arn, options \\ [])
View SourceGets the location of the table metadata.
definitions
Definitions
permissions
Permissions
You must have the s3tables:GetTableMetadataLocation permission to use this
operation.
get_table_policy(client, name, namespace, table_bucket_arn, options \\ [])
View SourceGets details about a table policy.
For more information, see Viewing a table policy in the Amazon Simple Storage Service User Guide.
definitions
Definitions
permissions
Permissions
You must have the s3tables:GetTablePolicy permission to use this operation.
list_namespaces(client, table_bucket_arn, continuation_token \\ nil, max_namespaces \\ nil, prefix \\ nil, options \\ [])
View SourceLists the namespaces within a table bucket.
For more information, see Table namespaces in the Amazon Simple Storage Service User Guide.
definitions
Definitions
permissions
Permissions
You must have the s3tables:ListNamespaces permission to use this operation.
list_table_buckets(client, continuation_token \\ nil, max_buckets \\ nil, prefix \\ nil, options \\ [])
View SourceLists table buckets for your account.
For more information, see S3 Table buckets in the Amazon Simple Storage Service User Guide.
definitions
Definitions
permissions
Permissions
You must have the s3tables:ListTableBuckets permission to use this operation.
list_tables(client, table_bucket_arn, continuation_token \\ nil, max_tables \\ nil, namespace \\ nil, prefix \\ nil, options \\ [])
View SourceList tables in the given table bucket.
For more information, see S3 Tables in the Amazon Simple Storage Service User Guide.
definitions
Definitions
permissions
Permissions
You must have the s3tables:ListTables permission to use this operation.
put_table_bucket_maintenance_configuration(client, table_bucket_arn, type, input, options \\ [])
View SourceCreates a new maintenance configuration or replaces an existing maintenance configuration for a table bucket.
For more information, see Amazon S3 table bucket maintenance in the Amazon Simple Storage Service User Guide.
definitions
Definitions
permissions
Permissions
You must have the s3tables:PutTableBucketMaintenanceConfiguration permission
to use this operation.
put_table_bucket_policy(client, table_bucket_arn, input, options \\ [])
View SourceCreates a new maintenance configuration or replaces an existing table bucket policy for a table bucket.
For more information, see Adding a table bucket policy in the Amazon Simple Storage Service User Guide.
definitions
Definitions
permissions
Permissions
You must have the s3tables:PutTableBucketPolicy permission to use this
operation.
put_table_maintenance_configuration(client, name, namespace, table_bucket_arn, type, input, options \\ [])
View SourceCreates a new maintenance configuration or replaces an existing maintenance configuration for a table.
For more information, see S3 Tables maintenance in the Amazon Simple Storage Service User Guide.
definitions
Definitions
permissions
Permissions
You must have the s3tables:PutTableMaintenanceConfiguration permission to use
this operation.
put_table_policy(client, name, namespace, table_bucket_arn, input, options \\ [])
View SourceCreates a new maintenance configuration or replaces an existing table policy for a table.
For more information, see Adding a table policy in the Amazon Simple Storage Service User Guide.
definitions
Definitions
permissions
Permissions
You must have the s3tables:PutTablePolicy permission to use this operation.
rename_table(client, name, namespace, table_bucket_arn, input, options \\ [])
View SourceRenames a table or a namespace.
For more information, see S3 Tables in the Amazon Simple Storage Service User Guide.
definitions
Definitions
permissions
Permissions
You must have the s3tables:RenameTable permission to use this operation.
update_table_metadata_location(client, name, namespace, table_bucket_arn, input, options \\ [])
View SourceUpdates the metadata location for a table.
The metadata location of a table must be an S3 URI that begins with the table's
warehouse location. The metadata location for an Apache Iceberg table must end
with .metadata.json, or if the metadata file is Gzip-compressed,
.metadata.json.gz.
definitions
Definitions
permissions
Permissions
You must have the s3tables:UpdateTableMetadataLocation permission to use this
operation.