View Source AWS.S3Vectors (aws-elixir v1.0.11)
Amazon S3 vector buckets are a bucket type to store and search vectors with sub-second search times.
They are designed to provide dedicated API operations for you to interact with vectors to do similarity search. Within a vector bucket, you use a vector index to organize and logically group your vector data. When you make a write or read request, you direct it to a single vector index. You store your vector data as vectors. A vector contains a key (a name that you assign), a multi-dimensional vector, and, optionally, metadata that describes a vector. The key uniquely identifies the vector in a vector index.
Link to this section Summary
Functions
Creates a vector index within a vector bucket.
Creates a vector bucket in the Amazon Web Services Region that you want your bucket to be in.
Deletes a vector index.
Deletes a vector bucket.
Deletes a vector bucket policy.
Deletes one or more vectors in a vector index.
Returns vector index attributes.
Returns vector bucket attributes.
Gets details about a vector bucket policy.
Returns vector attributes.
Returns a list of all the vector indexes within the specified vector bucket.
Lists all of the tags applied to a specified Amazon S3 Vectors resource.
Returns a list of all the vector buckets that are owned by the authenticated sender of the request.
List vectors in the specified vector index.
Creates a bucket policy for a vector bucket.
Adds one or more vectors to a vector index.
Performs an approximate nearest neighbor search query in a vector index using a query vector.
Applies one or more user-defined tags to an Amazon S3 Vectors resource or updates existing tags.
Removes the specified user-defined tags from an Amazon S3 Vectors resource.
Link to this section Functions
Creates a vector index within a vector bucket.
To specify the vector bucket, you must use either the vector bucket name or the vector bucket Amazon Resource Name (ARN).
definitions
Definitions
permissions
Permissions
You must have the s3vectors:CreateIndex permission to use this operation.
You must have the s3vectors:TagResource permission in addition to
s3vectors:CreateIndex permission to create a vector index with tags.
Creates a vector bucket in the Amazon Web Services Region that you want your bucket to be in.
definitions
Definitions
permissions
Permissions
You must have the s3vectors:CreateVectorBucket permission to use this
operation.
You must have the s3vectors:TagResource permission in addition to
s3vectors:CreateVectorBucket permission to create a vector bucket with tags.
Deletes a vector index.
To specify the vector index, you can either use both the vector bucket name and vector index name, or use the vector index Amazon Resource Name (ARN).
definitions
Definitions
permissions
Permissions
You must have the s3vectors:DeleteIndex permission to use this operation.
Deletes a vector bucket.
All vector indexes in the vector bucket must be deleted before the vector bucket can be deleted. To perform this operation, you must use either the vector bucket name or the vector bucket Amazon Resource Name (ARN).
definitions
Definitions
permissions
Permissions
You must have the s3vectors:DeleteVectorBucket permission to use this
operation.
Deletes a vector bucket policy.
To specify the bucket, you must use either the vector bucket name or the vector bucket Amazon Resource Name (ARN).
definitions
Definitions
permissions
Permissions
You must have the s3vectors:DeleteVectorBucketPolicy permission to use this
operation.
Deletes one or more vectors in a vector index.
To specify the vector index, you can either use both the vector bucket name and vector index name, or use the vector index Amazon Resource Name (ARN).
definitions
Definitions
permissions
Permissions
You must have the s3vectors:DeleteVectors permission to use this operation.
Returns vector index attributes.
To specify the vector index, you can either use both the vector bucket name and the vector index name, or use the vector index Amazon Resource Name (ARN).
definitions
Definitions
permissions
Permissions
You must have the s3vectors:GetIndex permission to use this operation.
Returns vector bucket attributes.
To specify the bucket, you must use either the vector bucket name or the vector bucket Amazon Resource Name (ARN).
definitions
Definitions
permissions
Permissions
You must have the s3vectors:GetVectorBucket permission to use this operation.
Gets details about a vector bucket policy.
To specify the bucket, you must use either the vector bucket name or the vector bucket Amazon Resource Name (ARN).
definitions
Definitions
permissions
Permissions
You must have the s3vectors:GetVectorBucketPolicy permission to use this
operation.
Returns vector attributes.
To specify the vector index, you can either use both the vector bucket name and the vector index name, or use the vector index Amazon Resource Name (ARN).
definitions
Definitions
permissions
Permissions
You must have the s3vectors:GetVectors permission to use this operation.
Returns a list of all the vector indexes within the specified vector bucket.
To specify the bucket, you must use either the vector bucket name or the vector bucket Amazon Resource Name (ARN).
definitions
Definitions
permissions
Permissions
You must have the s3vectors:ListIndexes permission to use this operation.
Lists all of the tags applied to a specified Amazon S3 Vectors resource.
Each tag is a label consisting of a key and value pair. Tags can help you organize, track costs for, and control access to resources.
For a list of S3 resources that support tagging, see Managing tags for Amazon S3 resources.
definitions
Definitions
permissions
Permissions
For vector buckets and vector indexes, you must have the
s3vectors:ListTagsForResource permission to use this operation.
Returns a list of all the vector buckets that are owned by the authenticated sender of the request.
definitions
Definitions
permissions
Permissions
You must have the s3vectors:ListVectorBuckets permission to use this
operation.
List vectors in the specified vector index.
To specify the vector index, you can either use both the vector bucket name and the vector index name, or use the vector index Amazon Resource Name (ARN).
ListVectors operations proceed sequentially; however, for faster performance
on a large number of vectors in a vector index, applications can request a
parallel ListVectors operation by providing the segmentCount and
segmentIndex parameters.
definitions
Definitions
permissions
Permissions
You must have the s3vectors:ListVectors permission to use this operation.
Additional permissions are required based on the request parameters you specify:
With only s3vectors:ListVectors permission, you can list vector
keys when returnData and returnMetadata are both set to false or not
specified..
If you set returnData or returnMetadata to true, you must have
both s3vectors:ListVectors and s3vectors:GetVectors permissions. The request
fails with a 403 Forbidden error if you request vector data or metadata
without the s3vectors:GetVectors permission.
Creates a bucket policy for a vector bucket.
To specify the bucket, you must use either the vector bucket name or the vector bucket Amazon Resource Name (ARN).
definitions
Definitions
permissions
Permissions
You must have the s3vectors:PutVectorBucketPolicy permission to use this
operation.
Adds one or more vectors to a vector index.
To specify the vector index, you can either use both the vector bucket name and the vector index name, or use the vector index Amazon Resource Name (ARN).
For more information about limits, see Limitations and restrictions in the Amazon S3 User Guide.
When inserting vector data into your vector index, you must provide the vector
data as float32 (32-bit floating point) values. If you pass higher-precision
values to an Amazon Web Services SDK, S3 Vectors converts the values to 32-bit
floating point before storing them, and GetVectors, ListVectors, and
QueryVectors operations return the float32 values. Different Amazon Web
Services SDKs may have different default numeric types, so ensure your vectors
are properly formatted as float32 values regardless of which SDK you're using.
For example, in Python, use numpy.float32 or explicitly cast your values.
definitions
Definitions
permissions
Permissions
You must have the s3vectors:PutVectors permission to use this operation.
Performs an approximate nearest neighbor search query in a vector index using a query vector.
By default, it returns the keys of approximate nearest neighbors. You can optionally include the computed distance (between the query vector and each vector in the response), the vector data, and metadata of each vector in the response.
To specify the vector index, you can either use both the vector bucket name and the vector index name, or use the vector index Amazon Resource Name (ARN).
definitions
Definitions
permissions
Permissions
You must have the s3vectors:QueryVectors permission to use this operation.
Additional permissions are required based on the request parameters you specify:
With only s3vectors:QueryVectors permission, you can retrieve
vector keys of approximate nearest neighbors and computed distances between
these vectors. This permission is sufficient only when you don't set any
metadata filters and don't request vector data or metadata (by keeping the
returnMetadata parameter set to false or not specified).
If you specify a metadata filter or set returnMetadata to true,
you must have both s3vectors:QueryVectors and s3vectors:GetVectors
permissions. The request fails with a 403 Forbidden error if you request
metadata filtering, vector data, or metadata without the s3vectors:GetVectors
permission.
Applies one or more user-defined tags to an Amazon S3 Vectors resource or updates existing tags.
Each tag is a label consisting of a key and value pair. Tags can help you organize, track costs for, and control access to your resources. You can add up to 50 tags for each resource.
For a list of S3 resources that support tagging, see Managing tags for Amazon S3 resources.
definitions
Definitions
permissions
Permissions
For vector buckets and vector indexes, you must have the s3vectors:TagResource
permission to use this operation.
Removes the specified user-defined tags from an Amazon S3 Vectors resource.
You can pass one or more tag keys.
For a list of S3 resources that support tagging, see Managing tags for Amazon S3 resources.
definitions
Definitions
permissions
Permissions
For vector buckets and vector indexes, you must have the
s3vectors:UntagResource permission to use this operation.